import os
import json
import random
import string
from datetime import datetime
from typing import Dict, Any, Optional, List
import logging

logger = logging.getLogger(__name__)

# 将所有配置文件统一放在 data/defaults 目录下
CLIENT_SERVICES_PATH = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'data', 'defaults', 'client_services.json')
AGENT_CLIENTS_PATH = os.path.join(os.path.dirname(os.path.dirname(__file__)), 'data', 'defaults', 'agent_clients.json')

class ClientManager:
    """管理客户端配置的类"""
    
    def __init__(self, services_path: Optional[str] = None, agent_clients_path: Optional[str] = None):
        """
        初始化客户端管理器

        Args:
            services_path: 客户端服务配置文件路径
            agent_clients_path: Agent客户端映射文件路径
        """
        self.services_path = services_path or CLIENT_SERVICES_PATH
        self.agent_clients_path = agent_clients_path or AGENT_CLIENTS_PATH
        self._ensure_file()
        self.client_services = self.load_all_clients()
        self.main_client_id = "main_client"  # 主客户端ID
        self._ensure_agent_clients_file()

    def _ensure_file(self):
        """确保客户端服务配置文件存在"""
        os.makedirs(os.path.dirname(self.services_path), exist_ok=True)
        if not os.path.exists(self.services_path):
            with open(self.services_path, 'w', encoding='utf-8') as f:
                json.dump({}, f)

    def _ensure_agent_clients_file(self):
        """确保agent-client映射文件存在"""
        os.makedirs(os.path.dirname(self.agent_clients_path), exist_ok=True)
        if not os.path.exists(self.agent_clients_path):
            with open(self.agent_clients_path, 'w', encoding='utf-8') as f:
                json.dump({}, f)

    def load_all_clients(self) -> Dict[str, Any]:
        """加载所有客户端配置"""
        with open(self.services_path, 'r', encoding='utf-8') as f:
            return json.load(f)

    def save_all_clients(self, data: Dict[str, Any]):
        """保存所有客户端配置"""
        with open(self.services_path, 'w', encoding='utf-8') as f:
            json.dump(data, f, ensure_ascii=False, indent=2)
        # 更新内存中的数据
        self.client_services = data.copy()

    def get_client_config(self, client_id: str) -> Optional[Dict[str, Any]]:
        """获取客户端配置"""
        # 每次都重新加载以确保数据最新
        self.client_services = self.load_all_clients()
        return self.client_services.get(client_id)

    def save_client_config(self, client_id: str, config: Dict[str, Any]):
        """保存客户端配置"""
        all_clients = self.load_all_clients()
        all_clients[client_id] = config
        self.save_all_clients(all_clients)
        logger.info(f"Saved config for client_id={client_id}")

    def generate_client_id(self) -> str:
        """生成唯一的客户端ID"""
        ts = datetime.now().strftime("%Y%m%d%H%M%S")
        rand = ''.join(random.choices(string.ascii_lowercase + string.digits, k=6))
        return f"client_{ts}_{rand}"

    def create_client_config_from_names(self, service_names: List[str], mcp_config: Dict[str, Any]) -> Dict[str, Any]:
        """从服务名称列表生成新的客户端配置"""
        all_services = mcp_config.get("mcpServers", {})
        selected = {name: all_services[name] for name in service_names if name in all_services}
        return {"mcpServers": selected}

    def add_client(self, config: Dict[str, Any], client_id: Optional[str] = None) -> str:
        """
        添加新的客户端配置
        
        Args:
            config: 客户端配置
            client_id: 可选的客户端ID，如果不提供则自动生成
            
        Returns:
            使用的客户端ID
        """
        if not client_id:
            client_id = self.generate_client_id()
        self.client_services[client_id] = config
        self.save_client_config(client_id, config)
        return client_id
    
    def remove_client(self, client_id: str) -> bool:
        """
        移除客户端配置
        
        Args:
            client_id: 要移除的客户端ID
            
        Returns:
            是否成功移除
        """
        if client_id in self.client_services:
            del self.client_services[client_id]
            self.save_all_clients(self.client_services)
            return True
        return False
    
    def has_client(self, client_id: str) -> bool:
        """
        检查客户端是否存在
        
        Args:
            client_id: 客户端ID
            
        Returns:
            是否存在
        """
        # 每次检查都重新加载以确保数据最新
        self.client_services = self.load_all_clients()
        return client_id in self.client_services
    
    def get_all_clients(self) -> Dict[str, Any]:
        """
        获取所有客户端配置
        
        Returns:
            所有客户端配置的字典
        """
        # 每次获取都重新加载以确保数据最新
        self.client_services = self.load_all_clients()
        return self.client_services.copy()

    # === agent_clients.json 相关 ===
    def load_all_agent_clients(self) -> Dict[str, Any]:
        """加载所有agent-client映射"""
        self._ensure_agent_clients_file()
        with open(self.agent_clients_path, 'r', encoding='utf-8') as f:
            return json.load(f)

    def save_all_agent_clients(self, data: Dict[str, Any]):
        """保存agent-client映射"""
        with open(self.agent_clients_path, 'w', encoding='utf-8') as f:
            json.dump(data, f, ensure_ascii=False, indent=2)

    def get_agent_clients(self, agent_id: str) -> List[str]:
        """
        获取指定 agent 下的所有 client_id
        """
        data = self.load_all_agent_clients()
        return data.get(agent_id, [])

    def add_agent_client_mapping(self, agent_id: str, client_id: str):
        """添加agent-client映射"""
        data = self.load_all_agent_clients()
        if agent_id not in data:
            data[agent_id] = [client_id]
        elif client_id not in data[agent_id]:
            data[agent_id].append(client_id)
        self.save_all_agent_clients(data)
        logger.info(f"Mapped agent_id={agent_id} to client_id={client_id}")

    def remove_agent_client_mapping(self, agent_id: str, client_id: str):
        """移除agent-client映射"""
        data = self.load_all_agent_clients()
        if agent_id in data and client_id in data[agent_id]:
            data[agent_id].remove(client_id)
            if not data[agent_id]:
                del data[agent_id]
            self.save_all_agent_clients(data)
            logger.info(f"Removed mapping agent_id={agent_id} to client_id={client_id}")

    def get_main_client_ids(self) -> List[str]:
        """获取 main_client 下的所有 client_id"""
        return list(self.get_all_clients().keys())

    def is_valid_client(self, client_id: str) -> bool:
        """检查是否是有效的 client_id"""
        return self.has_client(client_id)

    def find_clients_with_service(self, agent_id: str, service_name: str) -> List[str]:
        """
        查找指定Agent下包含特定服务的所有client_id

        Args:
            agent_id: Agent ID
            service_name: 服务名称

        Returns:
            包含该服务的client_id列表
        """
        client_ids = self.get_agent_clients(agent_id)
        matching_clients = []

        for client_id in client_ids:
            client_config = self.get_client_config(client_id)
            if client_config and service_name in client_config.get("mcpServers", {}):
                matching_clients.append(client_id)

        return matching_clients

    def replace_service_in_agent(self, agent_id: str, service_name: str, new_service_config: Dict[str, Any]) -> bool:
        """
        在指定Agent中替换同名服务

        Store级别：删除所有包含该服务的client，创建新client
        Agent级别：只替换包含该服务的client

        Args:
            agent_id: Agent ID (main_client for Store level)
            service_name: 服务名称
            new_service_config: 新的服务配置

        Returns:
            是否成功替换
        """
        try:
            # 1. 查找包含该服务的所有client_id
            matching_clients = self.find_clients_with_service(agent_id, service_name)

            if not matching_clients:
                # 没有找到同名服务，直接创建新的client
                logger.info(f"No existing service '{service_name}' found for agent {agent_id}, creating new client")
                return self._create_new_service_client(agent_id, service_name, new_service_config)

            # 2. Store级别：完全替换策略
            if agent_id == self.main_client_id:
                logger.info(f"Store level: Replacing service '{service_name}' in {len(matching_clients)} clients")

                # 删除所有包含该服务的旧client
                for client_id in matching_clients:
                    self._remove_client_and_mapping(agent_id, client_id)
                    logger.info(f"Removed old client {client_id} containing service '{service_name}'")

                # 创建新的client
                return self._create_new_service_client(agent_id, service_name, new_service_config)

            # 3. Agent级别：精确替换策略
            else:
                logger.info(f"Agent level: Replacing service '{service_name}' in {len(matching_clients)} clients for agent {agent_id}")

                # 对每个包含该服务的client进行替换
                for client_id in matching_clients:
                    client_config = self.get_client_config(client_id)
                    if client_config:
                        # 更新服务配置
                        client_config["mcpServers"][service_name] = new_service_config
                        self.save_client_config_with_return(client_id, client_config)
                        logger.info(f"Updated service '{service_name}' in client {client_id}")

                return True

        except Exception as e:
            logger.error(f"Failed to replace service '{service_name}' for agent {agent_id}: {e}")
            return False

    def _create_new_service_client(self, agent_id: str, service_name: str, service_config: Dict[str, Any]) -> bool:
        """
        为指定服务创建新的client

        Args:
            agent_id: Agent ID
            service_name: 服务名称
            service_config: 服务配置

        Returns:
            是否成功创建
        """
        try:
            # 生成新的client_id
            new_client_id = self.generate_client_id()

            # 创建client配置
            client_config = {
                "mcpServers": {
                    service_name: service_config
                }
            }

            # 保存client配置
            self.save_client_config_with_return(new_client_id, client_config)

            # 添加agent-client映射
            self.add_agent_client_mapping(agent_id, new_client_id)

            logger.info(f"Created new client {new_client_id} for service '{service_name}' under agent {agent_id}")
            return True

        except Exception as e:
            logger.error(f"Failed to create new client for service '{service_name}': {e}")
            return False

    def _remove_client_and_mapping(self, agent_id: str, client_id: str) -> bool:
        """
        删除client配置和agent映射

        Args:
            agent_id: Agent ID
            client_id: Client ID

        Returns:
            是否成功删除
        """
        try:
            # 删除client配置
            self.remove_client(client_id)

            # 删除agent-client映射
            self.remove_agent_client_mapping(agent_id, client_id)

            return True

        except Exception as e:
            logger.error(f"Failed to remove client {client_id} and mapping for agent {agent_id}: {e}")
            return False

    def add_agent_client_mapping(self, agent_id: str, client_id: str) -> bool:
        """
        添加Agent-Client映射关系

        Args:
            agent_id: Agent ID
            client_id: Client ID

        Returns:
            是否成功添加
        """
        try:
            data = self.load_all_agent_clients()
            if agent_id not in data:
                data[agent_id] = []

            if client_id not in data[agent_id]:
                data[agent_id].append(client_id)
                self.save_all_agent_clients(data)
                logger.info(f"Added client {client_id} to agent {agent_id}")

            return True

        except Exception as e:
            logger.error(f"Failed to add agent-client mapping: {e}")
            return False

    def remove_agent_client_mapping(self, agent_id: str, client_id: str) -> bool:
        """
        移除Agent-Client映射关系

        Args:
            agent_id: Agent ID
            client_id: Client ID

        Returns:
            是否成功移除
        """
        try:
            data = self.load_all_agent_clients()
            if agent_id in data and client_id in data[agent_id]:
                data[agent_id].remove(client_id)

                # 如果Agent没有任何Client了，删除Agent条目
                if not data[agent_id]:
                    del data[agent_id]

                self.save_all_agent_clients(data)
                logger.info(f"Removed client {client_id} from agent {agent_id}")

            return True

        except Exception as e:
            logger.error(f"Failed to remove agent-client mapping: {e}")
            return False

    def save_client_config_with_return(self, client_id: str, config: Dict[str, Any]) -> bool:
        """
        保存Client配置（带返回值版本）

        Args:
            client_id: Client ID
            config: Client配置

        Returns:
            是否成功保存
        """
        try:
            # 使用已存在的方法
            self.save_client_config(client_id, config)
            return True

        except Exception as e:
            logger.error(f"Failed to save client config: {e}")
            return False

    def reset_agent_config(self, agent_id: str) -> bool:
        """
        重置指定Agent的配置
        1. 删除该Agent的所有client配置
        2. 删除agent-client映射

        Args:
            agent_id: 要重置的Agent ID

        Returns:
            是否成功重置
        """
        try:
            # 获取该Agent的所有client_id
            client_ids = self.get_agent_clients(agent_id)

            # 删除所有client配置
            for client_id in client_ids:
                self.remove_client(client_id)
                logger.info(f"Removed client {client_id} for agent {agent_id}")

            # 删除agent-client映射
            data = self.load_all_agent_clients()
            if agent_id in data:
                del data[agent_id]
                self.save_all_agent_clients(data)
                logger.info(f"Removed agent-client mapping for agent {agent_id}")

            logger.info(f"Successfully reset config for agent {agent_id}")
            return True

        except Exception as e:
            logger.error(f"Failed to reset config for agent {agent_id}: {e}")
            return False

    # === 文件直接重置功能 ===
    def reset_client_services_file(self) -> bool:
        """
        直接重置client_services.json文件
        备份后重置为空字典

        Returns:
            是否成功重置
        """
        try:
            import shutil
            from datetime import datetime

            # 创建备份
            backup_path = f"{self.services_path}.backup.{datetime.now().strftime('%Y%m%d_%H%M%S')}"
            if os.path.exists(self.services_path):
                shutil.copy2(self.services_path, backup_path)
                logger.info(f"Created backup of client_services.json at {backup_path}")

            # 重置为空配置
            empty_config = {}
            self.save_all_clients(empty_config)

            logger.info("Successfully reset client_services.json file")
            return True

        except Exception as e:
            logger.error(f"Failed to reset client_services.json file: {e}")
            return False

    def reset_agent_clients_file(self) -> bool:
        """
        直接重置agent_clients.json文件
        备份后重置为空字典

        Returns:
            是否成功重置
        """
        try:
            import shutil
            from datetime import datetime

            # 创建备份
            backup_path = f"{self.agent_clients_path}.backup.{datetime.now().strftime('%Y%m%d_%H%M%S')}"
            if os.path.exists(self.agent_clients_path):
                shutil.copy2(self.agent_clients_path, backup_path)
                logger.info(f"Created backup of agent_clients.json at {backup_path}")

            # 重置为空配置
            empty_config = {}
            self.save_all_agent_clients(empty_config)

            logger.info("Successfully reset agent_clients.json file")
            return True

        except Exception as e:
            logger.error(f"Failed to reset agent_clients.json file: {e}")
            return False

    def remove_agent_from_files(self, agent_id: str) -> bool:
        """
        从文件中删除指定Agent的相关配置
        1. 从agent_clients.json中删除该agent的映射
        2. 从client_services.json中删除该agent关联的client配置

        Args:
            agent_id: 要删除的Agent ID

        Returns:
            是否成功删除
        """
        try:
            # 获取该Agent的所有client_id
            client_ids = self.get_agent_clients(agent_id)

            # 从client_services.json中删除相关client配置
            all_clients = self.load_all_clients()
            for client_id in client_ids:
                if client_id in all_clients:
                    del all_clients[client_id]
                    logger.info(f"Removed client {client_id} from client_services.json")
            self.save_all_clients(all_clients)

            # 从agent_clients.json中删除agent映射
            agent_data = self.load_all_agent_clients()
            if agent_id in agent_data:
                del agent_data[agent_id]
                self.save_all_agent_clients(agent_data)
                logger.info(f"Removed agent {agent_id} from agent_clients.json")

            logger.info(f"Successfully removed agent {agent_id} from all files")
            return True

        except Exception as e:
            logger.error(f"Failed to remove agent {agent_id} from files: {e}")
            return False

    def remove_store_from_files(self, main_client_id: str) -> bool:
        """
        从文件中删除Store(main_client)的相关配置
        1. 从client_services.json中删除main_client的配置
        2. 从agent_clients.json中删除main_client的映射

        Args:
            main_client_id: Store的main_client ID

        Returns:
            是否成功删除
        """
        try:
            # 从client_services.json中删除main_client配置
            all_clients = self.load_all_clients()
            if main_client_id in all_clients:
                del all_clients[main_client_id]
                self.save_all_clients(all_clients)
                logger.info(f"Removed main_client {main_client_id} from client_services.json")

            # 从agent_clients.json中删除main_client映射
            agent_data = self.load_all_agent_clients()
            if main_client_id in agent_data:
                del agent_data[main_client_id]
                self.save_all_agent_clients(agent_data)
                logger.info(f"Removed main_client {main_client_id} from agent_clients.json")

            logger.info(f"Successfully removed store main_client {main_client_id} from all files")
            return True

        except Exception as e:
            logger.error(f"Failed to remove store main_client {main_client_id} from files: {e}")
            return False





#!/usr/bin/env python3
"""
统一工具名称解析器 - 基于 FastMCP 官网标准
提供用户友好的工具名称输入，内部转换为 FastMCP 标准格式
"""

import re
import logging
from typing import Tuple, Optional, List, Dict, Any
from dataclasses import dataclass

logger = logging.getLogger(__name__)

@dataclass
class ToolResolution:
    """工具解析结果"""
    service_name: str           # 服务名称
    original_tool_name: str     # FastMCP 标准的原始工具名
    user_input: str            # 用户输入的工具名
    resolution_method: str     # 解析方法 (exact_match, prefix_match, fuzzy_match)

class ToolNameResolver:
    """
    统一工具名称解析器

    设计原则：
    1. 用户友好：支持多种输入格式
    2. FastMCP 标准：内部严格按照官网标准处理
    3. 智能解析：自动识别服务和工具
    4. 服务名校验：使用单下划线 + 精确服务名匹配
    """

    def __init__(self, available_services: List[str] = None):
        """
        初始化解析器

        Args:
            available_services: 可用服务列表，用于智能匹配
        """
        self.available_services = available_services or []
        self._service_tools_cache: Dict[str, List[str]] = {}

        # 预处理服务名映射（原始名 -> 标准化名）
        self._service_name_mapping = {}
        for service in self.available_services:
            normalized = self._normalize_service_name(service)
            self._service_name_mapping[normalized] = service
            # 同时支持原始名称
            self._service_name_mapping[service] = service
    
    def resolve_tool_name(self, user_input: str, available_tools: List[Dict[str, Any]] = None) -> ToolResolution:
        """
        解析用户输入的工具名称

        Args:
            user_input: 用户输入的工具名称
            available_tools: 可用工具列表 [{"name": "display_name", "original_name": "tool", "service_name": "service"}]

        Returns:
            ToolResolution: 解析结果

        Raises:
            ValueError: 无法解析工具名称
        """
        if not user_input or not isinstance(user_input, str):
            raise ValueError("Tool name cannot be empty")

        user_input = user_input.strip()
        available_tools = available_tools or []

        # 构建工具映射（支持显示名称和原始名称）
        display_to_original = {}  # 显示名称 -> (原始名称, 服务名)
        original_to_service = {}  # 原始名称 -> 服务名
        service_tools = {}        # 服务名 -> [原始工具名列表]

        for tool in available_tools:
            display_name = tool.get("name", "")  # 显示名称
            original_name = tool.get("original_name") or tool.get("name", "")  # 原始名称
            service_name = tool.get("service_name", "")

            display_to_original[display_name] = (original_name, service_name)
            original_to_service[original_name] = service_name

            if service_name not in service_tools:
                service_tools[service_name] = []
            if original_name not in service_tools[service_name]:
                service_tools[service_name].append(original_name)

        logger.debug(f"Resolving tool: {user_input}")
        logger.debug(f"Available services: {list(service_tools.keys())}")

        # 1. 精确匹配：显示名称
        if user_input in display_to_original:
            original_name, service_name = display_to_original[user_input]
            return ToolResolution(
                service_name=service_name,
                original_tool_name=original_name,
                user_input=user_input,
                resolution_method="exact_display_match"
            )

        # 2. 精确匹配：原始名称
        if user_input in original_to_service:
            return ToolResolution(
                service_name=original_to_service[user_input],
                original_tool_name=user_input,
                user_input=user_input,
                resolution_method="exact_original_match"
            )

        # 3. 单下划线格式解析：service_tool（精确服务名匹配）
        if "_" in user_input and "__" not in user_input:
            # 尝试所有可能的分割点
            for i in range(1, len(user_input)):
                if user_input[i] == "_":
                    potential_service = user_input[:i]
                    potential_tool = user_input[i+1:]

                    # 检查是否有匹配的服务（支持原始名称和标准化名称）
                    matched_service = None
                    if potential_service in service_tools:
                        matched_service = potential_service
                    elif potential_service in self._service_name_mapping:
                        matched_service = self._service_name_mapping[potential_service]

                    if matched_service and potential_tool in service_tools[matched_service]:
                        logger.debug(f"Single underscore match: {potential_service} -> {matched_service}, tool: {potential_tool}")
                        return ToolResolution(
                            service_name=matched_service,
                            original_tool_name=potential_tool,
                            user_input=user_input,
                            resolution_method="single_underscore_match"
                        )

        # 4. 检查是否使用了废弃的双下划线格式
        if "__" in user_input:
            parts = user_input.split("__", 1)
            if len(parts) == 2:
                potential_service, potential_tool = parts
                single_underscore_format = f"{potential_service}_{potential_tool}"
                raise ValueError(
                    f"Double underscore format '__' is no longer supported. "
                    f"Please use single underscore format: '{single_underscore_format}'"
                )

        # 5. 模糊匹配：在所有工具中查找相似名称
        fuzzy_matches = []
        for display_name, (original_name, service_name) in display_to_original.items():
            if self._is_fuzzy_match(user_input, display_name) or self._is_fuzzy_match(user_input, original_name):
                fuzzy_matches.append((original_name, service_name, display_name))

        if len(fuzzy_matches) == 1:
            original_name, service_name, display_name = fuzzy_matches[0]
            return ToolResolution(
                service_name=service_name,
                original_tool_name=original_name,
                user_input=user_input,
                resolution_method="fuzzy_match"
            )
        elif len(fuzzy_matches) > 1:
            # 多个匹配，提供建议
            suggestions = [display_name for _, _, display_name in fuzzy_matches[:3]]
            raise ValueError(f"Ambiguous tool name '{user_input}'. Did you mean: {', '.join(suggestions)}?")

        # 6. 无法解析，提供建议
        if available_tools:
            all_display_names = list(display_to_original.keys())
            suggestions = self._get_suggestions(user_input, all_display_names)
            if suggestions:
                raise ValueError(f"Tool '{user_input}' not found. Did you mean: {', '.join(suggestions[:3])}?")

        raise ValueError(f"Tool '{user_input}' not found")
    
    def create_user_friendly_name(self, service_name: str, tool_name: str) -> str:
        """
        创建用户友好的工具名称（用于显示）

        使用单下划线格式，保持服务名的原始形式

        Args:
            service_name: 服务名称（保持原始格式）
            tool_name: 原始工具名称

        Returns:
            用户友好的工具名称
        """
        # 使用单下划线，保持服务名原始格式
        return f"{service_name}_{tool_name}"
    
    def _normalize_service_name(self, service_name: str) -> str:
        """标准化服务名称"""
        # 移除特殊字符，转换为下划线
        normalized = re.sub(r'[^a-zA-Z0-9_]', '_', service_name)
        # 移除连续下划线
        normalized = re.sub(r'_+', '_', normalized)
        # 移除首尾下划线
        normalized = normalized.strip('_')
        return normalized or "unnamed"
    
    def _is_fuzzy_match(self, user_input: str, tool_name: str) -> bool:
        """检查是否为模糊匹配"""
        user_lower = user_input.lower()
        tool_lower = tool_name.lower()
        
        # 完全包含
        if user_lower in tool_lower or tool_lower in user_lower:
            return True
        
        # 去除下划线后匹配
        user_clean = user_lower.replace('_', '').replace('-', '')
        tool_clean = tool_lower.replace('_', '').replace('-', '')
        
        if user_clean in tool_clean or tool_clean in user_clean:
            return True
        
        return False
    
    def _get_suggestions(self, user_input: str, available_names: List[str]) -> List[str]:
        """获取建议的工具名称"""
        suggestions = []
        user_lower = user_input.lower()
        
        for name in available_names:
            name_lower = name.lower()
            # 前缀匹配
            if name_lower.startswith(user_lower) or user_lower.startswith(name_lower):
                suggestions.append(name)
            # 包含匹配
            elif user_lower in name_lower or name_lower in user_lower:
                suggestions.append(name)
        
        return sorted(suggestions, key=lambda x: len(x))[:5]

class FastMCPToolExecutor:
    """
    FastMCP 标准工具执行器
    严格按照官网标准执行工具调用
    """
    
    def __init__(self, default_timeout: float = 30.0):
        """
        初始化执行器
        
        Args:
            default_timeout: 默认超时时间（秒）
        """
        self.default_timeout = default_timeout
    
    async def execute_tool(
        self,
        client,
        tool_name: str,
        arguments: Dict[str, Any] = None,
        timeout: Optional[float] = None,
        progress_handler = None,
        raise_on_error: bool = True
    ) -> 'CallToolResult':
        """
        执行工具（严格按照 FastMCP 官网标准）
        
        Args:
            client: FastMCP 客户端实例
            tool_name: 工具名称（FastMCP 原始名称）
            arguments: 工具参数
            timeout: 超时时间（秒）
            progress_handler: 进度处理器
            raise_on_error: 是否在错误时抛出异常
            
        Returns:
            CallToolResult: FastMCP 标准结果对象
        """
        arguments = arguments or {}
        timeout = timeout or self.default_timeout
        
        try:
            # 根据实际的 FastMCP 2.7.1 版本调用
            call_kwargs = {
                "name": tool_name,
                "arguments": arguments
            }

            # 添加支持的参数
            if timeout is not None:
                call_kwargs["timeout"] = timeout
            if progress_handler is not None:
                call_kwargs["progress_handler"] = progress_handler

            # FastMCP 2.7.1 的 call_tool 返回 list[TextContent|ImageContent|EmbeddedResource]
            # 而不是 CallToolResult，所以我们需要使用 call_tool_mcp 来获取完整结果
            if hasattr(client, 'call_tool_mcp'):
                # 使用 call_tool_mcp 获取 CallToolResult
                logger.debug(f"Using call_tool_mcp for complete result")
                result = await client.call_tool_mcp(**call_kwargs)

                # 手动处理 raise_on_error 逻辑
                if hasattr(result, 'is_error') and result.is_error and raise_on_error:
                    error_msg = "Tool execution failed"
                    if hasattr(result, 'content') and result.content:
                        for content in result.content:
                            if hasattr(content, 'text'):
                                error_msg = content.text
                                break
                    raise Exception(error_msg)

                return result
            else:
                # 回退到普通的 call_tool
                logger.debug(f"Using standard call_tool")
                content_list = await client.call_tool(**call_kwargs)

                # 将内容列表包装成类似 CallToolResult 的对象
                from types import SimpleNamespace
                result = SimpleNamespace(
                    content=content_list,
                    is_error=False,
                    data=None,
                    structured_content=None
                )

                return result

        except Exception as e:
            logger.error(f"Tool '{tool_name}' execution failed: {e}")
            if raise_on_error:
                raise
            else:
                # 返回错误结果
                from types import SimpleNamespace
                return SimpleNamespace(
                    content=[],
                    is_error=True,
                    data=None,
                    structured_content=None,
                    error=str(e)
                )
    
    def extract_result_data(self, result: 'CallToolResult') -> Any:
        """
        提取结果数据（严格按照 FastMCP 官网标准）

        根据官方文档的优先级顺序：
        1. .data - FastMCP 独有的完全水合 Python 对象
        2. .structured_content - 标准 MCP 结构化 JSON 数据
        3. .content - 标准 MCP 内容块

        Args:
            result: FastMCP 调用结果

        Returns:
            提取的数据
        """
        import logging
        logger = logging.getLogger(__name__)

        # 检查错误状态
        if hasattr(result, 'is_error') and result.is_error:
            logger.warning(f"Tool execution failed, extracting error content")
            # 即使是错误，也尝试提取内容

        # 1. 优先使用 .data 属性（FastMCP 独有特性）
        if hasattr(result, 'data') and result.data is not None:
            logger.debug(f"Using FastMCP .data property: {type(result.data)}")
            return result.data

        # 2. 回退到 .structured_content（标准 MCP 结构化数据）
        if hasattr(result, 'structured_content') and result.structured_content is not None:
            logger.debug(f"Using MCP .structured_content: {result.structured_content}")
            return result.structured_content

        # 3. 最后使用 .content（标准 MCP 内容块）
        if hasattr(result, 'content') and result.content:
            logger.debug(f"Using MCP .content blocks: {len(result.content)} items")

            # 按照官方文档，content 是 ContentBlock 列表
            if isinstance(result.content, list) and result.content:
                # 优先返回第一个文本内容块的文本
                for content_block in result.content:
                    if hasattr(content_block, 'text'):
                        logger.debug(f"Extracting text from TextContent: {content_block.text}")
                        return content_block.text
                    elif hasattr(content_block, 'data'):
                        logger.debug(f"Found binary content: {len(content_block.data)} bytes")
                        # 对于二进制内容，返回数据本身
                        return content_block.data

                # 如果没有找到可提取的内容，返回第一个内容块
                logger.debug(f"No extractable content found, returning first content block")
                return result.content[0]

            # 如果 content 不是列表，直接返回
            return result.content

        # 4. 如果以上都没有数据，返回 None（符合官方文档的 fallback 行为）
        logger.debug("No extractable data found in any standard properties, returning None")
        return None



"""
数据空间管理器
负责初始化和维护store的数据目录，确保每个store有独立的数据空间
"""

import json
import shutil
from pathlib import Path
from datetime import datetime
from typing import Dict, Any, Optional, Callable
import logging

logger = logging.getLogger(__name__)

class DataSpaceManager:
    """数据空间管理器 - 负责初始化和维护store的数据目录"""
    
    # 必需文件定义 - 保持与默认配置一致的层级结构
    REQUIRED_FILES = {
        "defaults/agent_clients.json": {
            "template": {},
            "description": "Agent客户端映射文件"
        },
        "defaults/client_services.json": {
            "template": {},
            "description": "客户端服务映射文件"
        },
        "monitoring/alerts.json": {
            "template": [],
            "description": "监控告警数据文件"
        },
        "monitoring/tool_usage.json": {
            "template": {},
            "description": "工具使用统计文件"
        },
        "monitoring/monitoring_stats.json": {
            "template": {
                "daily_api_calls": {},
                "tool_usage": {},
                "network_endpoints": []
            },
            "description": "监控统计数据文件"
        }
    }
    
    # MCP JSON文件的基础模板
    MCP_JSON_TEMPLATE = {
        "mcpServers": {},
        "version": "1.0.0",
        "created_by": "MCPStore",
        "created_at": None,
        "description": "MCPStore configuration file"
    }
    
    def __init__(self, mcp_json_path: str):
        """
        初始化数据空间管理器
        
        Args:
            mcp_json_path: MCP JSON配置文件路径
        """
        self.mcp_json_path = Path(mcp_json_path).resolve()
        self.workspace_dir = self.mcp_json_path.parent
        
        logger.info(f"DataSpaceManager initialized for workspace: {self.workspace_dir}")
    
    def initialize_workspace(self) -> bool:
        """
        初始化工作空间，确保所有必需文件存在且有效
        
        Returns:
            bool: 初始化是否成功
        """
        try:
            logger.info(f"Initializing workspace: {self.workspace_dir}")
            
            # 1. 确保工作空间目录存在
            self.workspace_dir.mkdir(parents=True, exist_ok=True)
            
            # 2. 检查和处理MCP JSON文件
            if not self._validate_and_fix_mcp_json():
                logger.error("Failed to validate/fix MCP JSON file")
                return False
            
            # 3. 检查和创建必需文件
            if not self._ensure_required_files():
                logger.error("Failed to ensure required files")
                return False
            
            logger.info("Workspace initialization completed successfully")
            return True
            
        except Exception as e:
            logger.error(f"Workspace initialization failed: {e}")
            return False
    
    def _validate_and_fix_mcp_json(self) -> bool:
        """
        验证和修复MCP JSON文件
        
        Returns:
            bool: 处理是否成功
        """
        try:
            if not self.mcp_json_path.exists():
                logger.info(f"MCP JSON file not found, creating: {self.mcp_json_path}")
                return self._create_mcp_json()
            
            # 尝试读取和验证现有文件
            try:
                with open(self.mcp_json_path, 'r', encoding='utf-8') as f:
                    data = json.load(f)
                
                # 验证文件结构
                if self._validate_mcp_json_structure(data):
                    logger.info("MCP JSON file is valid")
                    return True
                else:
                    logger.warning("MCP JSON file structure is invalid, will backup and recreate")
                    return self._backup_and_recreate_mcp_json()
                    
            except json.JSONDecodeError as e:
                logger.warning(f"MCP JSON file has syntax errors: {e}, will backup and recreate")
                return self._backup_and_recreate_mcp_json()
            except Exception as e:
                logger.warning(f"Error reading MCP JSON file: {e}, will backup and recreate")
                return self._backup_and_recreate_mcp_json()
                
        except Exception as e:
            logger.error(f"Failed to validate/fix MCP JSON: {e}")
            return False
    
    def _validate_mcp_json_structure(self, data: Dict[str, Any]) -> bool:
        """
        验证MCP JSON文件结构
        
        Args:
            data: JSON数据
            
        Returns:
            bool: 结构是否有效
        """
        # 检查必需字段
        if not isinstance(data, dict):
            return False
        
        # 检查mcpServers字段
        if "mcpServers" not in data:
            return False
        
        if not isinstance(data["mcpServers"], dict):
            return False
        
        # 基本结构有效
        return True
    
    def _backup_and_recreate_mcp_json(self) -> bool:
        """
        备份现有文件并重新创建MCP JSON文件
        
        Returns:
            bool: 操作是否成功
        """
        try:
            # 创建备份
            timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
            backup_path = self.mcp_json_path.with_suffix(f'.backup_{timestamp}.json')
            
            if self.mcp_json_path.exists():
                shutil.copy2(self.mcp_json_path, backup_path)
                logger.info(f"Backup created: {backup_path}")
            
            # 重新创建文件
            return self._create_mcp_json()
            
        except Exception as e:
            logger.error(f"Failed to backup and recreate MCP JSON: {e}")
            return False
    
    def _create_mcp_json(self) -> bool:
        """
        创建新的MCP JSON文件
        
        Returns:
            bool: 创建是否成功
        """
        try:
            template = self.MCP_JSON_TEMPLATE.copy()
            template["created_at"] = datetime.now().isoformat()
            
            with open(self.mcp_json_path, 'w', encoding='utf-8') as f:
                json.dump(template, f, indent=2, ensure_ascii=False)
            
            logger.info(f"Created new MCP JSON file: {self.mcp_json_path}")
            return True
            
        except Exception as e:
            logger.error(f"Failed to create MCP JSON file: {e}")
            return False
    
    def _ensure_required_files(self) -> bool:
        """
        确保所有必需文件存在且有效
        
        Returns:
            bool: 操作是否成功
        """
        try:
            for file_path, config in self.REQUIRED_FILES.items():
                full_path = self.workspace_dir / file_path
                
                # 确保目录存在
                full_path.parent.mkdir(parents=True, exist_ok=True)
                
                if not full_path.exists():
                    # 文件不存在，创建新文件
                    self._create_file_from_template(full_path, config)
                    logger.info(f"Created missing file: {full_path}")
                else:
                    # 文件存在，验证格式
                    if not self._validate_json_file(full_path):
                        # 文件格式错误，备份并重新创建
                        self._backup_and_recreate_file(full_path, config)
                        logger.warning(f"Recreated invalid file: {full_path}")
            
            return True
            
        except Exception as e:
            logger.error(f"Failed to ensure required files: {e}")
            return False
    
    def _create_file_from_template(self, file_path: Path, config: Dict[str, Any]) -> bool:
        """
        从模板创建文件
        
        Args:
            file_path: 文件路径
            config: 文件配置
            
        Returns:
            bool: 创建是否成功
        """
        try:
            with open(file_path, 'w', encoding='utf-8') as f:
                json.dump(config["template"], f, indent=2, ensure_ascii=False)
            return True
        except Exception as e:
            logger.error(f"Failed to create file {file_path}: {e}")
            return False
    
    def _validate_json_file(self, file_path: Path) -> bool:
        """
        验证JSON文件格式
        
        Args:
            file_path: 文件路径
            
        Returns:
            bool: 文件是否有效
        """
        try:
            with open(file_path, 'r', encoding='utf-8') as f:
                json.load(f)
            return True
        except (json.JSONDecodeError, Exception):
            return False
    
    def _backup_and_recreate_file(self, file_path: Path, config: Dict[str, Any]) -> bool:
        """
        备份并重新创建文件
        
        Args:
            file_path: 文件路径
            config: 文件配置
            
        Returns:
            bool: 操作是否成功
        """
        try:
            # 创建备份
            timestamp = datetime.now().strftime("%Y%m%d_%H%M%S")
            backup_path = file_path.with_suffix(f'.backup_{timestamp}.json')
            
            if file_path.exists():
                shutil.copy2(file_path, backup_path)
                logger.info(f"Backup created: {backup_path}")
            
            # 重新创建文件
            return self._create_file_from_template(file_path, config)
            
        except Exception as e:
            logger.error(f"Failed to backup and recreate file {file_path}: {e}")
            return False
    
    def get_file_path(self, file_type: str) -> Path:
        """
        获取特定类型文件的路径
        
        Args:
            file_type: 文件类型 (如: 'agent_clients.json', 'monitoring/alerts.json')
            
        Returns:
            Path: 文件路径
        """
        if file_type == "mcp.json":
            return self.mcp_json_path
        
        if file_type in self.REQUIRED_FILES:
            return self.workspace_dir / file_type
        
        # 对于其他文件，直接返回相对于workspace的路径
        return self.workspace_dir / file_type
    
    def get_workspace_info(self) -> Dict[str, Any]:
        """
        获取工作空间信息
        
        Returns:
            Dict: 工作空间信息
        """
        info = {
            "workspace_dir": str(self.workspace_dir),
            "mcp_json_path": str(self.mcp_json_path),
            "files": {}
        }
        
        # 检查MCP JSON文件
        info["files"]["mcp.json"] = {
            "exists": self.mcp_json_path.exists(),
            "path": str(self.mcp_json_path)
        }
        
        # 检查必需文件
        for file_type in self.REQUIRED_FILES:
            file_path = self.get_file_path(file_type)
            info["files"][file_type] = {
                "exists": file_path.exists(),
                "path": str(file_path),
                "description": self.REQUIRED_FILES[file_type]["description"]
            }
        
        return info



"""
MCPStore 监控和统计模块
提供性能监控、工具使用统计、告警管理等功能
"""

import asyncio
import time
import psutil
import json
from datetime import datetime, timedelta
from typing import Dict, List, Optional, Any
from dataclasses import dataclass, asdict
from pathlib import Path
import aiohttp
import logging

logger = logging.getLogger(__name__)

@dataclass
class PerformanceMetrics:
    """性能指标数据类"""
    api_response_time: float  # API平均响应时间(ms)
    active_connections: int   # 活跃连接数
    today_api_calls: int     # 今日API调用数
    memory_usage: float      # 内存使用率(%)
    cpu_usage: float         # CPU使用率(%)
    uptime: float           # 运行时间(秒)

@dataclass
class ToolUsageStats:
    """工具使用统计数据类"""
    tool_name: str
    service_name: str
    execution_count: int
    last_executed: Optional[str]
    average_response_time: float
    success_rate: float

@dataclass
class AlertInfo:
    """告警信息数据类"""
    alert_id: str
    type: str  # 'warning', 'error', 'info'
    title: str
    message: str
    timestamp: str
    service_name: Optional[str] = None
    resolved: bool = False

@dataclass
class NetworkEndpoint:
    """网络端点监控数据类"""
    endpoint_name: str
    url: str
    status: str  # 'healthy', 'warning', 'error'
    response_time: float
    last_checked: str
    uptime_percentage: float

@dataclass
class SystemResourceInfo:
    """系统资源信息数据类"""
    server_uptime: str
    memory_total: int
    memory_used: int
    memory_percentage: float
    disk_usage_percentage: float
    network_traffic_in: int
    network_traffic_out: int

class MonitoringManager:
    """监控管理器"""
    
    def __init__(self, data_dir: Path):
        self.data_dir = data_dir
        self.stats_file = data_dir / "monitoring_stats.json"
        self.alerts_file = data_dir / "alerts.json"
        self.tool_usage_file = data_dir / "tool_usage.json"
        
        # 运行时统计
        self.start_time = time.time()
        self.api_call_times = []
        self.api_call_count = 0
        self.active_connections = 0
        
        # 确保数据文件存在
        self._ensure_data_files()
    
    def _ensure_data_files(self):
        """确保数据文件存在"""
        self.data_dir.mkdir(parents=True, exist_ok=True)
        
        if not self.stats_file.exists():
            self.stats_file.write_text(json.dumps({
                "daily_api_calls": {},
                "tool_usage": {},
                "network_endpoints": []
            }, indent=2))
        
        if not self.alerts_file.exists():
            self.alerts_file.write_text(json.dumps([], indent=2))
        
        if not self.tool_usage_file.exists():
            self.tool_usage_file.write_text(json.dumps({}, indent=2))
    
    def record_api_call(self, response_time: float):
        """记录API调用"""
        self.api_call_count += 1
        self.api_call_times.append(response_time)
        
        # 只保留最近100次调用的响应时间
        if len(self.api_call_times) > 100:
            self.api_call_times = self.api_call_times[-100:]
        
        # 记录今日调用数
        today = datetime.now().strftime("%Y-%m-%d")
        try:
            with open(self.stats_file, 'r') as f:
                stats = json.load(f)
            
            if "daily_api_calls" not in stats:
                stats["daily_api_calls"] = {}
            
            stats["daily_api_calls"][today] = stats["daily_api_calls"].get(today, 0) + 1
            
            with open(self.stats_file, 'w') as f:
                json.dump(stats, f, indent=2)
        except Exception as e:
            logger.error(f"Failed to record API call: {e}")
    
    def record_tool_execution(self, tool_name: str, service_name: str, 
                            response_time: float, success: bool):
        """记录工具执行"""
        try:
            with open(self.tool_usage_file, 'r') as f:
                usage_data = json.load(f)
            
            key = f"{service_name}:{tool_name}"
            if key not in usage_data:
                usage_data[key] = {
                    "tool_name": tool_name,
                    "service_name": service_name,
                    "execution_count": 0,
                    "total_response_time": 0.0,
                    "success_count": 0,
                    "last_executed": None
                }
            
            tool_stats = usage_data[key]
            tool_stats["execution_count"] += 1
            tool_stats["total_response_time"] = float(tool_stats["total_response_time"]) + response_time
            tool_stats["last_executed"] = datetime.now().isoformat()
            
            if success:
                tool_stats["success_count"] += 1
            
            with open(self.tool_usage_file, 'w') as f:
                json.dump(usage_data, f, indent=2)
                
        except Exception as e:
            logger.error(f"Failed to record tool execution: {e}")
    
    def add_alert(self, alert_type: str, title: str, message: str, 
                  service_name: Optional[str] = None) -> str:
        """添加告警"""
        alert_id = f"alert_{int(time.time() * 1000)}"
        alert = AlertInfo(
            alert_id=alert_id,
            type=alert_type,
            title=title,
            message=message,
            timestamp=datetime.now().isoformat(),
            service_name=service_name
        )
        
        try:
            with open(self.alerts_file, 'r') as f:
                alerts = json.load(f)
            
            alerts.append(asdict(alert))
            
            # 只保留最近50个告警
            if len(alerts) > 50:
                alerts = alerts[-50:]
            
            with open(self.alerts_file, 'w') as f:
                json.dump(alerts, f, indent=2)
            
            return alert_id
        except Exception as e:
            logger.error(f"Failed to add alert: {e}")
            return ""
    
    def get_performance_metrics(self) -> PerformanceMetrics:
        """获取性能指标"""
        # API响应时间
        avg_response_time = (
            sum(self.api_call_times) / len(self.api_call_times) 
            if self.api_call_times else 0
        )
        
        # 今日API调用数
        today = datetime.now().strftime("%Y-%m-%d")
        today_calls = 0
        try:
            with open(self.stats_file, 'r') as f:
                stats = json.load(f)
            today_calls = stats.get("daily_api_calls", {}).get(today, 0)
        except:
            pass
        
        # 系统资源
        memory = psutil.virtual_memory()
        cpu_percent = psutil.cpu_percent(interval=0.1)
        uptime = time.time() - self.start_time
        
        return PerformanceMetrics(
            api_response_time=round(avg_response_time, 2),
            active_connections=self.active_connections,
            today_api_calls=today_calls,
            memory_usage=round(memory.percent, 1),
            cpu_usage=round(cpu_percent, 1),
            uptime=round(uptime, 1)
        )
    
    def get_tool_usage_stats(self, limit: int = 10) -> List[ToolUsageStats]:
        """获取工具使用统计"""
        try:
            with open(self.tool_usage_file, 'r') as f:
                usage_data = json.load(f)
            
            stats = []
            for key, data in usage_data.items():
                if data["execution_count"] > 0:
                    avg_response_time = data["total_response_time"] / data["execution_count"]
                    success_rate = data["success_count"] / data["execution_count"] * 100
                    
                    stats.append(ToolUsageStats(
                        tool_name=data["tool_name"],
                        service_name=data["service_name"],
                        execution_count=data["execution_count"],
                        last_executed=data["last_executed"],
                        average_response_time=round(avg_response_time, 2),
                        success_rate=round(success_rate, 1)
                    ))
            
            # 按执行次数排序
            stats.sort(key=lambda x: x.execution_count, reverse=True)
            return stats[:limit]
            
        except Exception as e:
            logger.error(f"Failed to get tool usage stats: {e}")
            return []
    
    def get_alerts(self, unresolved_only: bool = False) -> List[AlertInfo]:
        """获取告警列表"""
        try:
            with open(self.alerts_file, 'r') as f:
                alerts_data = json.load(f)
            
            alerts = [AlertInfo(**alert) for alert in alerts_data]
            
            if unresolved_only:
                alerts = [alert for alert in alerts if not alert.resolved]
            
            # 按时间倒序
            alerts.sort(key=lambda x: x.timestamp, reverse=True)
            return alerts
            
        except Exception as e:
            logger.error(f"Failed to get alerts: {e}")
            return []
    
    def resolve_alert(self, alert_id: str) -> bool:
        """解决告警"""
        try:
            with open(self.alerts_file, 'r') as f:
                alerts_data = json.load(f)
            
            for alert in alerts_data:
                if alert["alert_id"] == alert_id:
                    alert["resolved"] = True
                    break
            
            with open(self.alerts_file, 'w') as f:
                json.dump(alerts_data, f, indent=2)
            
            return True
        except Exception as e:
            logger.error(f"Failed to resolve alert: {e}")
            return False
    
    def clear_all_alerts(self) -> bool:
        """清除所有告警"""
        try:
            with open(self.alerts_file, 'w') as f:
                json.dump([], f, indent=2)
            return True
        except Exception as e:
            logger.error(f"Failed to clear alerts: {e}")
            return False
    
    async def check_network_endpoints(self, endpoints: List[Dict[str, str]]) -> List[NetworkEndpoint]:
        """检查网络端点状态"""
        results = []
        
        async with aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=5)) as session:
            for endpoint in endpoints:
                name = endpoint.get("name", "Unknown")
                url = endpoint.get("url", "")
                
                start_time = time.time()
                status = "error"
                response_time = 0
                
                try:
                    async with session.get(url) as response:
                        response_time = (time.time() - start_time) * 1000
                        if response.status == 200:
                            status = "healthy" if response_time < 1000 else "warning"
                        else:
                            status = "warning"
                except:
                    status = "error"
                    response_time = 5000  # 超时
                
                results.append(NetworkEndpoint(
                    endpoint_name=name,
                    url=url,
                    status=status,
                    response_time=round(response_time, 2),
                    last_checked=datetime.now().isoformat(),
                    uptime_percentage=95.0  # 简化实现，实际应该基于历史数据
                ))
        
        return results
    
    def get_system_resource_info(self) -> SystemResourceInfo:
        """获取系统资源信息"""
        # 内存信息
        memory = psutil.virtual_memory()
        
        # 磁盘信息
        disk = psutil.disk_usage('/')
        
        # 网络信息
        net_io = psutil.net_io_counters()
        
        # 运行时间
        uptime_seconds = time.time() - self.start_time
        uptime_str = str(timedelta(seconds=int(uptime_seconds)))
        
        return SystemResourceInfo(
            server_uptime=uptime_str,
            memory_total=memory.total,
            memory_used=memory.used,
            memory_percentage=round(memory.percent, 1),
            disk_usage_percentage=round(disk.percent, 1),
            network_traffic_in=net_io.bytes_recv,
            network_traffic_out=net_io.bytes_sent
        )
    
    def increment_active_connections(self):
        """增加活跃连接数"""
        self.active_connections += 1
    
    def decrement_active_connections(self):
        """减少活跃连接数"""
        self.active_connections = max(0, self.active_connections - 1)



#!/usr/bin/env python3
"""
工具转换功能 (Tool Transformation)
基于 FastMCP 2.8 的工具转换能力，提供 LLM 友好的工具接口
"""

import logging
from typing import Dict, List, Any, Optional, Callable, Union
from dataclasses import dataclass, field
from enum import Enum

logger = logging.getLogger(__name__)

class TransformationType(Enum):
    """转换类型"""
    RENAME_ARGS = "rename_args"           # 重命名参数
    HIDE_ARGS = "hide_args"               # 隐藏参数
    MODIFY_DESCRIPTION = "modify_description"  # 修改描述
    ADD_VALIDATION = "add_validation"     # 添加验证
    SIMPLIFY_INTERFACE = "simplify_interface"  # 简化接口
    ENHANCE_SAFETY = "enhance_safety"     # 增强安全性

@dataclass
class ArgumentTransform:
    """参数转换配置"""
    original_name: str
    new_name: Optional[str] = None        # 新参数名
    hidden: bool = False                  # 是否隐藏
    default_value: Any = None             # 默认值
    description: Optional[str] = None     # 新描述
    validation_fn: Optional[Callable] = None  # 验证函数
    transform_fn: Optional[Callable] = None   # 转换函数

@dataclass
class ToolTransformConfig:
    """工具转换配置"""
    original_tool_name: str
    new_tool_name: Optional[str] = None
    new_description: Optional[str] = None
    argument_transforms: Dict[str, ArgumentTransform] = field(default_factory=dict)
    pre_execution_hooks: List[Callable] = field(default_factory=list)
    post_execution_hooks: List[Callable] = field(default_factory=list)
    tags: List[str] = field(default_factory=list)
    enabled: bool = True

class ToolTransformer:
    """工具转换器"""
    
    def __init__(self):
        self._transformations: Dict[str, ToolTransformConfig] = {}
        self._original_tools: Dict[str, Any] = {}
    
    def register_transformation(self, config: ToolTransformConfig) -> str:
        """
        注册工具转换配置
        
        Args:
            config: 转换配置
            
        Returns:
            str: 转换后的工具名称
        """
        transformed_name = config.new_tool_name or f"{config.original_tool_name}_enhanced"
        self._transformations[transformed_name] = config
        
        logger.info(f"Registered tool transformation: {config.original_tool_name} -> {transformed_name}")
        return transformed_name
    
    def create_llm_friendly_tool(
        self,
        original_tool_name: str,
        friendly_name: Optional[str] = None,
        simplified_description: Optional[str] = None,
        hide_technical_params: bool = True,
        add_safety_checks: bool = True
    ) -> str:
        """
        创建 LLM 友好的工具版本
        
        Args:
            original_tool_name: 原始工具名
            friendly_name: 友好名称
            simplified_description: 简化描述
            hide_technical_params: 是否隐藏技术参数
            add_safety_checks: 是否添加安全检查
            
        Returns:
            str: 转换后的工具名称
        """
        config = ToolTransformConfig(
            original_tool_name=original_tool_name,
            new_tool_name=friendly_name or f"{original_tool_name}_simple",
            new_description=simplified_description,
            tags=["llm-friendly", "simplified"]
        )
        
        if hide_technical_params:
            # 隐藏常见的技术参数
            technical_params = ["timeout", "retry_count", "debug", "verbose", "raw_output"]
            for param in technical_params:
                config.argument_transforms[param] = ArgumentTransform(
                    original_name=param,
                    hidden=True,
                    default_value=self._get_default_for_param(param)
                )
        
        if add_safety_checks:
            # 添加安全检查钩子
            config.pre_execution_hooks.append(self._safety_check_hook)
        
        return self.register_transformation(config)
    
    def create_parameter_renamed_tool(
        self,
        original_tool_name: str,
        parameter_mapping: Dict[str, str],
        new_tool_name: Optional[str] = None
    ) -> str:
        """
        创建参数重命名的工具版本
        
        Args:
            original_tool_name: 原始工具名
            parameter_mapping: 参数映射 {原参数名: 新参数名}
            new_tool_name: 新工具名
            
        Returns:
            str: 转换后的工具名称
        """
        config = ToolTransformConfig(
            original_tool_name=original_tool_name,
            new_tool_name=new_tool_name or f"{original_tool_name}_renamed",
            tags=["parameter-renamed"]
        )
        
        for original_param, new_param in parameter_mapping.items():
            config.argument_transforms[original_param] = ArgumentTransform(
                original_name=original_param,
                new_name=new_param
            )
        
        return self.register_transformation(config)
    
    def create_validated_tool(
        self,
        original_tool_name: str,
        validation_rules: Dict[str, Callable],
        new_tool_name: Optional[str] = None
    ) -> str:
        """
        创建带验证的工具版本
        
        Args:
            original_tool_name: 原始工具名
            validation_rules: 验证规则 {参数名: 验证函数}
            new_tool_name: 新工具名
            
        Returns:
            str: 转换后的工具名称
        """
        config = ToolTransformConfig(
            original_tool_name=original_tool_name,
            new_tool_name=new_tool_name or f"{original_tool_name}_validated",
            tags=["validated", "safe"]
        )
        
        for param_name, validation_fn in validation_rules.items():
            config.argument_transforms[param_name] = ArgumentTransform(
                original_name=param_name,
                validation_fn=validation_fn
            )
        
        return self.register_transformation(config)
    
    def get_transformation_config(self, tool_name: str) -> Optional[ToolTransformConfig]:
        """获取工具转换配置"""
        return self._transformations.get(tool_name)
    
    def list_transformed_tools(self) -> List[str]:
        """列出所有转换后的工具"""
        return list(self._transformations.keys())
    
    def _get_default_for_param(self, param_name: str) -> Any:
        """获取参数的默认值"""
        defaults = {
            "timeout": 30.0,
            "retry_count": 3,
            "debug": False,
            "verbose": False,
            "raw_output": False
        }
        return defaults.get(param_name)
    
    def _safety_check_hook(self, tool_name: str, args: Dict[str, Any]) -> Dict[str, Any]:
        """安全检查钩子"""
        # 基本的安全检查
        if not isinstance(args, dict):
            raise ValueError("Arguments must be a dictionary")
        
        # 检查危险参数
        dangerous_keys = ["__", "eval", "exec", "import", "open", "file"]
        for key in args:
            if any(dangerous in str(key).lower() for dangerous in dangerous_keys):
                logger.warning(f"Potentially dangerous parameter detected: {key}")
        
        return args

class ToolTransformationManager:
    """工具转换管理器"""
    
    def __init__(self):
        self.transformer = ToolTransformer()
        self._enabled_transformations: Dict[str, bool] = {}
    
    def create_simple_weather_tool(self, original_tool_name: str) -> str:
        """创建简化的天气工具"""
        return self.transformer.create_llm_friendly_tool(
            original_tool_name=original_tool_name,
            friendly_name="get_weather",
            simplified_description="Get current weather for a city. Just provide the city name.",
            hide_technical_params=True,
            add_safety_checks=True
        )
    
    def create_user_friendly_api_tool(self, original_tool_name: str, api_type: str) -> str:
        """创建用户友好的 API 工具"""
        friendly_names = {
            "weather": "check_weather",
            "news": "get_news",
            "search": "search_web",
            "translate": "translate_text",
            "image": "process_image"
        }
        
        return self.transformer.create_llm_friendly_tool(
            original_tool_name=original_tool_name,
            friendly_name=friendly_names.get(api_type, f"use_{api_type}"),
            simplified_description=f"Easy-to-use {api_type} tool with simplified parameters.",
            hide_technical_params=True,
            add_safety_checks=True
        )
    
    def enable_transformation(self, tool_name: str, enabled: bool = True):
        """启用/禁用工具转换"""
        self._enabled_transformations[tool_name] = enabled
        logger.info(f"Tool transformation {tool_name} {'enabled' if enabled else 'disabled'}")
    
    def is_transformation_enabled(self, tool_name: str) -> bool:
        """检查工具转换是否启用"""
        return self._enabled_transformations.get(tool_name, True)
    
    def get_transformation_summary(self) -> Dict[str, Any]:
        """获取转换摘要"""
        return {
            "total_transformations": len(self.transformer._transformations),
            "enabled_transformations": sum(1 for enabled in self._enabled_transformations.values() if enabled),
            "available_tools": self.transformer.list_transformed_tools(),
            "transformation_types": [
                "llm-friendly",
                "parameter-renamed", 
                "validated",
                "simplified"
            ]
        }

# 全局实例
_global_transformation_manager = None

def get_transformation_manager() -> ToolTransformationManager:
    """获取全局工具转换管理器"""
    global _global_transformation_manager
    if _global_transformation_manager is None:
        _global_transformation_manager = ToolTransformationManager()
    return _global_transformation_manager



"""
MCPStore API 路由
提供所有 HTTP API 端点，保持与 MCPStore 核心方法的一致性
"""

from fastapi import APIRouter, HTTPException, Depends
from mcpstore import MCPStore
from mcpstore.core.models.service import (
    RegisterRequestUnion, JsonUpdateRequest,
    ServiceInfoResponse, ServicesResponse
)
from mcpstore.core.models.tool import (
    ToolExecutionRequest, ToolsResponse
)
from pydantic import BaseModel, Field
from mcpstore.core.models.common import (
    APIResponse, RegistrationResponse, ConfigResponse,
    ExecutionResponse
)
from mcpstore.core.monitoring import (
    PerformanceMetrics, ToolUsageStats, AlertInfo,
    NetworkEndpoint, SystemResourceInfo
)
from typing import Optional, List, Dict, Any, Union
from pydantic import BaseModel, ValidationError, Field
import logging
import traceback
from functools import wraps
from datetime import timedelta
import asyncio
import time

# 创建logger实例
logger = logging.getLogger(__name__)

# === 监控相关的响应模型 ===

class PerformanceMetricsResponse(BaseModel):
    """性能指标响应"""
    api_response_time: float = Field(description="API平均响应时间(ms)")
    active_connections: int = Field(description="活跃连接数")
    today_api_calls: int = Field(description="今日API调用数")
    memory_usage: float = Field(description="内存使用率(%)")
    cpu_usage: float = Field(description="CPU使用率(%)")
    uptime: float = Field(description="运行时间(秒)")

class ToolUsageStatsResponse(BaseModel):
    """工具使用统计响应"""
    tool_name: str = Field(description="工具名称")
    service_name: str = Field(description="服务名称")
    execution_count: int = Field(description="执行次数")
    last_executed: Optional[str] = Field(description="最后执行时间")
    average_response_time: float = Field(description="平均响应时间")
    success_rate: float = Field(description="成功率")

class AlertInfoResponse(BaseModel):
    """告警信息响应"""
    alert_id: str = Field(description="告警ID")
    type: str = Field(description="告警类型")
    title: str = Field(description="告警标题")
    message: str = Field(description="告警消息")
    timestamp: str = Field(description="告警时间")
    service_name: Optional[str] = Field(description="相关服务名称")
    resolved: bool = Field(description="是否已解决")

class NetworkEndpointResponse(BaseModel):
    """网络端点响应"""
    endpoint_name: str = Field(description="端点名称")
    url: str = Field(description="端点URL")
    status: str = Field(description="状态")
    response_time: float = Field(description="响应时间")
    last_checked: str = Field(description="最后检查时间")
    uptime_percentage: float = Field(description="可用性百分比")

class SystemResourceInfoResponse(BaseModel):
    """系统资源信息响应"""
    server_uptime: str = Field(description="服务器运行时间")
    memory_total: int = Field(description="总内存")
    memory_used: int = Field(description="已用内存")
    memory_percentage: float = Field(description="内存使用率")
    disk_usage_percentage: float = Field(description="磁盘使用率")
    network_traffic_in: int = Field(description="网络入流量")
    network_traffic_out: int = Field(description="网络出流量")

class AddAlertRequest(BaseModel):
    """添加告警请求"""
    type: str = Field(description="告警类型: warning, error, info")
    title: str = Field(description="告警标题")
    message: str = Field(description="告警消息")
    service_name: Optional[str] = Field(None, description="相关服务名称")

class NetworkEndpointCheckRequest(BaseModel):
    """网络端点检查请求"""
    endpoints: List[Dict[str, str]] = Field(description="端点列表")

# 简化的工具执行请求模型（用于API）
class SimpleToolExecutionRequest(BaseModel):
    tool_name: str = Field(..., description="工具名称")
    args: Dict[str, Any] = Field(default_factory=dict, description="工具参数")
    service_name: Optional[str] = Field(None, description="服务名称（可选，会自动推断）")

# === 统一响应模型 ===
# APIResponse 已移动到 common.py 中，通过导入使用

# === 监控配置模型 ===
class MonitoringConfig(BaseModel):
    """监控配置模型"""
    heartbeat_interval_seconds: Optional[int] = Field(default=None, ge=10, le=300, description="心跳检查间隔（秒），范围10-300")
    reconnection_interval_seconds: Optional[int] = Field(default=None, ge=10, le=600, description="重连尝试间隔（秒），范围10-600")
    cleanup_interval_hours: Optional[int] = Field(default=None, ge=1, le=24, description="资源清理间隔（小时），范围1-24")
    max_reconnection_queue_size: Optional[int] = Field(default=None, ge=10, le=200, description="最大重连队列大小，范围10-200")
    max_heartbeat_history_hours: Optional[int] = Field(default=None, ge=1, le=168, description="心跳历史保留时间（小时），范围1-168")
    http_timeout_seconds: Optional[int] = Field(default=None, ge=1, le=30, description="HTTP超时时间（秒），范围1-30")

# === 工具函数 ===
def handle_exceptions(func):
    """统一的异常处理装饰器"""
    @wraps(func)
    async def wrapper(*args, **kwargs):
        try:
            result = await func(*args, **kwargs)
            # 如果结果已经是APIResponse，直接返回
            if isinstance(result, APIResponse):
                return result
            # 否则包装成APIResponse
            return APIResponse(success=True, data=result)
        except HTTPException:
            # HTTPException应该直接传递，不要包装
            raise
        except ValidationError as e:
            # Pydantic验证错误，返回400
            raise HTTPException(status_code=400, detail=f"Validation error: {str(e)}")
        except ValueError as e:
            raise HTTPException(status_code=400, detail=str(e))
        except Exception as e:
            raise HTTPException(status_code=500, detail=str(e))
    return wrapper

def monitor_api_performance(func):
    """API性能监控装饰器"""
    @wraps(func)
    async def wrapper(*args, **kwargs):
        start_time = time.time()

        # 获取store实例（从依赖注入中）
        store = None
        for arg in args:
            if isinstance(arg, MCPStore):
                store = arg
                break

        # 如果没有在args中找到，检查kwargs
        if store is None:
            store = kwargs.get('store')

        try:
            # 增加活跃连接数
            store = get_store()
            if store:
                store.for_store().increment_active_connections()

            result = await func(*args, **kwargs)

            # 记录API调用
            if store:
                response_time = (time.time() - start_time) * 1000  # 转换为毫秒
                store.for_store().record_api_call(response_time)

            return result
        finally:
            # 减少活跃连接数
            if store:
                store.for_store().decrement_active_connections()

    return wrapper

def validate_agent_id(agent_id: str):
    """验证 agent_id"""
    if not agent_id:
        raise HTTPException(status_code=400, detail="agent_id is required")
    if not isinstance(agent_id, str):
        raise HTTPException(status_code=400, detail="Invalid agent_id format")

    # 检查agent_id格式：只允许字母、数字、下划线、连字符
    import re
    if not re.match(r'^[a-zA-Z0-9_-]+$', agent_id):
        raise HTTPException(status_code=400, detail="Invalid agent_id format: only letters, numbers, underscore and hyphen allowed")

    # 检查长度
    if len(agent_id) > 100:
        raise HTTPException(status_code=400, detail="agent_id too long (max 100 characters)")

def validate_service_names(service_names: Optional[List[str]]):
    """验证 service_names"""
    if service_names and not isinstance(service_names, list):
        raise HTTPException(status_code=400, detail="Invalid service_names format")
    if service_names and not all(isinstance(name, str) for name in service_names):
        raise HTTPException(status_code=400, detail="All service names must be strings")

router = APIRouter()

# === 依赖注入函数 ===
def get_store() -> MCPStore:
    """获取MCPStore实例的依赖注入函数"""
    # 从api_app模块获取当前的store实例
    from .api_app import get_store as get_app_store
    return get_app_store()

# === Store 级别操作 ===
@router.post("/for_store/add_service", response_model=APIResponse)
@handle_exceptions
async def store_add_service(
    payload: Optional[Dict[str, Any]] = None
):
    """Store 级别注册服务
    支持三种模式：
    1. 空参数注册：注册所有 mcp.json 中的服务
       POST /for_store/add_service
    
    2. URL方式添加服务：
       POST /for_store/add_service
       {
           "name": "weather",
           "url": "https://weather-api.example.com/mcp",
           "transport": "streamable-http"
       }
    
    3. 命令方式添加服务（本地服务）：
       POST /for_store/add_service
       {
           "name": "assistant",
           "command": "python",
           "args": ["./assistant_server.py"],
           "env": {"DEBUG": "true"},
           "working_dir": "/path/to/service"
       }

       注意：本地服务需要确保：
       - 命令路径正确且可执行
       - 工作目录存在且有权限
       - 环境变量设置正确
    
    Returns:
        APIResponse: {
            "success": true/false,
            "data": true/false,  # 是否成功添加服务
            "message": "错误信息（如果有）"
        }
    """
    try:
        store = get_store()
        store = get_store()

        context = store.for_store()

        # 1. 空参数注册
        if not payload:
            result = await context.add_service_async()
            success = result is not None
            return APIResponse(
                success=success,
                data=success,
                message="Successfully registered all services" if success else "Failed to register services"
            )

        # 2/3. 配置方式添加服务 - 直接使用SDK的详细处理方法
        # SDK已经包含了所有业务逻辑：配置验证、transport推断、服务名解析等
        result = await context.add_service_with_details_async(payload)

        # 直接返回SDK处理的结果，只需要包装成APIResponse格式
        return APIResponse(
            success=result["success"],
            data={
                "added_services": result["added_services"],
                "failed_services": result["failed_services"],
                "service_details": result["service_details"],
                "total_services": result["total_services"],
                "total_tools": result["total_tools"]
            },
            message=result["message"]
        )

    except Exception as e:
        logger.error(f"Failed to add service: {str(e)}")
        logger.error(f"Traceback: {traceback.format_exc()}")
        raise HTTPException(status_code=500, detail=f"Failed to add service: {str(e)}")

@router.get("/for_store/list_services", response_model=APIResponse)
@handle_exceptions
async def store_list_services():
    """Store 级别获取服务列表"""
    try:
        store = get_store()
        store = get_store()

        context = store.for_store()
        services = context.list_services()

        return APIResponse(
            success=True,
            data=services,
            message=f"Retrieved {len(services)} services successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to retrieve services: {str(e)}"
        )

@router.get("/for_store/list_tools", response_model=APIResponse)
@handle_exceptions
async def store_list_tools():
    """Store 级别获取工具列表"""
    try:
        store = get_store()
        store = get_store()

        context = store.for_store()
        # 使用SDK的统计方法
        result = context.get_tools_with_stats()

        return APIResponse(
            success=True,
            data=result["tools"],
            metadata=result["metadata"],
            message=f"Retrieved {result['metadata']['total_tools']} tools from {result['metadata']['services_count']} services"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to retrieve tools: {str(e)}"
        )

@router.get("/for_store/check_services", response_model=APIResponse)
@handle_exceptions
async def store_check_services():
    """Store 级别健康检查"""
    try:
        store = get_store()
        store = get_store()

        context = store.for_store()
        health_status = context.check_services()

        return APIResponse(
            success=True,
            data=health_status,
            message="Health check completed successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={"error": str(e)},
            message=f"Health check failed: {str(e)}"
        )

@router.post("/for_store/use_tool", response_model=APIResponse)
@handle_exceptions
async def store_use_tool(request: SimpleToolExecutionRequest):
    """Store 级别使用工具"""
    if not request.tool_name or not isinstance(request.tool_name, str):
        raise HTTPException(status_code=400, detail="tool_name is required and must be a string")
    if request.args is None or not isinstance(request.args, dict):
        raise HTTPException(status_code=400, detail="args is required and must be a dictionary")

    try:
        import time
        import uuid

        # 记录执行开始时间
        start_time = time.time()
        trace_id = str(uuid.uuid4())[:8]

        # 🔧 直接使用SDK的use_tool_async方法，它已经包含了完整的工具解析逻辑
        # SDK会自动处理：工具名称解析、服务推断、格式转换等
        store = get_store()
        store = get_store()

        store = get_store()


        result = await store.for_store().use_tool_async(request.tool_name, request.args)

        # 计算执行时间
        duration_ms = int((time.time() - start_time) * 1000)

        # 📊 记录工具执行统计
        try:
            # 从工具名提取服务名
            service_name = request.tool_name.split('_')[0] if '_' in request.tool_name else 'unknown'

            # 判断执行是否成功
            success = True
            if hasattr(result, 'is_error') and result.is_error:
                success = False
            elif isinstance(result, dict) and result.get('error'):
                success = False

            # 记录工具执行（store已在函数开头获取）
            store.for_store().record_tool_execution(
                request.tool_name,
                service_name,
                duration_ms,
                success
            )
        except Exception as e:
            # 监控记录失败不应该影响工具执行
            logger.warning(f"Failed to record tool execution: {e}")

        # 提取实际结果（SDK返回的是FastMCP标准结果）
        actual_result = result.result if hasattr(result, 'result') else result

        return APIResponse(
            success=True,
            data=actual_result,
            execution_info={
                "duration_ms": duration_ms,
                "tool_version": "1.0.0",
                "service_name": "auto-resolved",  # SDK已经处理了服务解析
                "trace_id": trace_id
            },
            message=f"Tool '{request.tool_name}' executed successfully"
        )
    except HTTPException:
        raise
    except Exception as e:
        # 📊 记录失败的工具执行
        try:
            duration_ms = int((time.time() - start_time) * 1000)
            service_name = request.tool_name.split('_')[0] if '_' in request.tool_name else 'unknown'

            # 获取store实例记录失败的工具执行
            store = get_store()
            store.for_store().record_tool_execution(
                request.tool_name,
                service_name,
                duration_ms,
                False  # 执行失败
            )
        except Exception as monitor_error:
            logger.warning(f"Failed to record failed tool execution: {monitor_error}")

        # 如果工具存在但执行失败，仍然返回成功但包含错误信息
        return APIResponse(
            success=False,
            data={"error": str(e)},
            message=f"Tool '{request.tool_name}' execution failed: {str(e)}"
        )

# === Agent 级别操作 ===
@router.post("/for_agent/{agent_id}/add_service", response_model=APIResponse)
@handle_exceptions
async def agent_add_service(
    agent_id: str,
    payload: Union[List[str], Dict[str, Any]]
):
    """Agent 级别注册服务
    支持两种模式：
    1. 通过服务名列表注册：
       POST /for_agent/{agent_id}/add_service
       ["服务名1", "服务名2"]
    
    2. 通过配置添加：
       POST /for_agent/{agent_id}/add_service
       {
           "name": "新服务",
           "command": "python",
           "args": ["service.py"],
           "env": {"DEBUG": "true"}
       }
    
    Args:
        agent_id: Agent ID
        payload: 服务配置或服务名列表
    
    Returns:
        APIResponse: {
            "success": true/false,
            "data": true/false,  # 是否成功添加服务
            "message": "错误信息（如果有）"
        }
    """
    try:
        validate_agent_id(agent_id)
        store = get_store()
        context = store.for_agent(agent_id)
        
        # 直接使用SDK的详细处理方法，支持所有格式
        # SDK已经包含了所有业务逻辑：配置验证、transport推断、服务名解析等
        result = await context.add_service_with_details_async(payload)

        # 直接返回SDK处理的结果，只需要包装成APIResponse格式
        return APIResponse(
            success=result["success"],
            data={
                "added_services": result["added_services"],
                "failed_services": result["failed_services"],
                "service_details": result["service_details"],
                "total_services": result["total_services"],
                "total_tools": result["total_tools"]
            },
            message=result["message"]
        )

        
    except HTTPException:
        raise
    except Exception as e:
        raise HTTPException(status_code=500, detail=f"Failed to add service for agent '{agent_id}': {str(e)}")

@router.get("/for_agent/{agent_id}/list_services", response_model=APIResponse)
@handle_exceptions
async def agent_list_services(agent_id: str):
    """Agent 级别获取服务列表"""
    try:
        validate_agent_id(agent_id)
        store = get_store()
        context = store.for_agent(agent_id)
        services = await context.list_services()

        return APIResponse(
            success=True,
            data=services,
            message=f"Retrieved {len(services)} services for agent '{agent_id}'"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to retrieve services for agent '{agent_id}': {str(e)}"
        )

@router.get("/for_agent/{agent_id}/list_tools", response_model=APIResponse)
@handle_exceptions
async def agent_list_tools(agent_id: str):
    """Agent 级别获取工具列表"""
    try:
        validate_agent_id(agent_id)
        store = get_store()
        context = store.for_agent(agent_id)
        # 使用SDK的统计方法
        result = context.get_tools_with_stats()

        return APIResponse(
            success=True,
            data=result["tools"],
            metadata=result["metadata"],
            message=f"Retrieved {result['metadata']['total_tools']} tools from {result['metadata']['services_count']} services for agent '{agent_id}'"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to retrieve tools for agent '{agent_id}': {str(e)}"
        )

@router.get("/for_agent/{agent_id}/check_services", response_model=APIResponse)
@handle_exceptions
async def agent_check_services(agent_id: str):
    """Agent 级别健康检查"""
    try:
        validate_agent_id(agent_id)
        store = get_store()
        context = store.for_agent(agent_id)
        health_status = await context.check_services_async()

        return APIResponse(
            success=True,
            data=health_status,
            message=f"Health check completed for agent '{agent_id}'"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={"error": str(e)},
            message=f"Health check failed for agent '{agent_id}': {str(e)}"
        )

@router.post("/for_agent/{agent_id}/use_tool", response_model=APIResponse)
@handle_exceptions
async def agent_use_tool(agent_id: str, request: SimpleToolExecutionRequest):
    """Agent 级别使用工具"""
    validate_agent_id(agent_id)
    if not request.tool_name or not isinstance(request.tool_name, str):
        raise HTTPException(status_code=400, detail="tool_name is required and must be a string")
    if request.args is None or not isinstance(request.args, dict):
        raise HTTPException(status_code=400, detail="args is required and must be a dictionary")

    try:
        import time
        import uuid

        # 记录执行开始时间
        start_time = time.time()
        trace_id = str(uuid.uuid4())[:8]

        # 🔧 直接使用SDK的use_tool_async方法，它已经包含了完整的工具解析逻辑
        store = get_store()
        result = await store.for_agent(agent_id).use_tool_async(request.tool_name, request.args)

        # 计算执行时间
        duration_ms = int((time.time() - start_time) * 1000)

        # 📊 记录工具执行统计
        try:
            # 从工具名提取服务名
            service_name = request.tool_name.split('_')[0] if '_' in request.tool_name else 'unknown'

            # 判断执行是否成功
            success = True
            if hasattr(result, 'is_error') and result.is_error:
                success = False
            elif isinstance(result, dict) and result.get('error'):
                success = False

            # 记录工具执行
            store = get_store()

            store.for_agent(agent_id).record_tool_execution(
                request.tool_name,
                service_name,
                duration_ms,
                success
            )
        except Exception as e:
            # 监控记录失败不应该影响工具执行
            logger.warning(f"Failed to record tool execution for agent {agent_id}: {e}")

        # 提取实际结果
        actual_result = result.result if hasattr(result, 'result') else result

        return APIResponse(
            success=True,
            data=actual_result,
            execution_info={
                "duration_ms": duration_ms,
                "tool_version": "1.0.0",
                "service_name": "auto-resolved",  # SDK已经处理了服务解析
                "agent_id": agent_id,
                "trace_id": trace_id
            },
            message=f"Tool '{request.tool_name}' executed successfully for agent '{agent_id}'"
        )
    except HTTPException:
        raise
    except Exception as e:
        # 📊 记录失败的工具执行
        try:
            duration_ms = int((time.time() - start_time) * 1000)
            service_name = request.tool_name.split('_')[0] if '_' in request.tool_name else 'unknown'

            store = get_store()


            store.for_agent(agent_id).record_tool_execution(
                request.tool_name,
                service_name,
                duration_ms,
                False  # 执行失败
            )
        except Exception as monitor_error:
            logger.warning(f"Failed to record failed tool execution for agent {agent_id}: {monitor_error}")

        return APIResponse(
            success=False,
            data={"error": str(e)},
            message=f"Tool '{request.tool_name}' execution failed for agent '{agent_id}': {str(e)}"
        )

# === 通用服务信息查询 ===
@router.get("/services/{name}", response_model=APIResponse)
@handle_exceptions
async def get_service_info(name: str, agent_id: Optional[str] = None):
    """获取服务信息，支持 Store/Agent 上下文"""
    if agent_id:
        validate_agent_id(agent_id)
        return await store.for_agent(agent_id).get_service_info_async(name)
    return await store.for_store().get_service_info_async(name)

# === Store 级别服务管理操作 ===
@router.post("/for_store/delete_service", response_model=APIResponse)
@handle_exceptions
async def store_delete_service(request: Dict[str, str]):
    """Store 级别删除服务"""
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        store = get_store()

        store = get_store()


        result = await store.for_store().delete_service_async(service_name)
        return APIResponse(
            success=result,
            data=result,
            message=f"Service {service_name} deleted successfully" if result else f"Failed to delete service {service_name}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to delete service {service_name}: {str(e)}"
        )

@router.post("/for_store/update_service", response_model=APIResponse)
@handle_exceptions
async def store_update_service(request: Dict[str, Any]):
    """Store 级别更新服务配置"""
    service_name = request.get("name")
    config = request.get("config")

    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")
    if not config:
        raise HTTPException(status_code=400, detail="Service config is required")

    try:
        store = get_store()

        store = get_store()


        result = await store.for_store().update_service_async(service_name, config)
        return APIResponse(
            success=result,
            data=result,
            message=f"Service {service_name} updated successfully" if result else f"Failed to update service {service_name}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to update service {service_name}: {str(e)}"
        )

@router.post("/for_store/restart_service", response_model=APIResponse)
@handle_exceptions
async def store_restart_service(request: Dict[str, str]):
    """Store 级别重启服务"""
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        store = get_store()

        context = store.for_store()

        # 获取服务配置
        service_info = await context.get_service_info_async(service_name)
        if not service_info:
            raise HTTPException(status_code=404, detail=f"Service {service_name} not found")

        # 删除服务
        delete_result = await context.delete_service_async(service_name)
        if not delete_result:
            raise HTTPException(status_code=500, detail=f"Failed to stop service {service_name}")

        # 重新添加服务
        add_result = await context.add_service_async([service_name])

        return APIResponse(
            success=add_result,
            data=add_result,
            message=f"Service {service_name} restarted successfully" if add_result else f"Failed to restart service {service_name}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to restart service {service_name}: {str(e)}"
        )

# === Agent 级别服务管理操作 ===
@router.post("/for_agent/{agent_id}/delete_service", response_model=APIResponse)
@handle_exceptions
async def agent_delete_service(agent_id: str, request: Dict[str, str]):
    """Agent 级别删除服务"""
    validate_agent_id(agent_id)
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        result = await store.for_agent(agent_id).delete_service_async(service_name)
        return APIResponse(
            success=result,
            data=result,
            message=f"Service {service_name} deleted successfully" if result else f"Failed to delete service {service_name}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to delete service {service_name}: {str(e)}"
        )

@router.post("/for_agent/{agent_id}/update_service", response_model=APIResponse)
@handle_exceptions
async def agent_update_service(agent_id: str, request: Dict[str, Any]):
    """Agent 级别更新服务配置"""
    validate_agent_id(agent_id)
    service_name = request.get("name")
    config = request.get("config")

    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")
    if not config:
        raise HTTPException(status_code=400, detail="Service config is required")

    try:
        result = await store.for_agent(agent_id).update_service_async(service_name, config)
        return APIResponse(
            success=result,
            data=result,
            message=f"Service {service_name} updated successfully" if result else f"Failed to update service {service_name}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to update service {service_name}: {str(e)}"
        )

@router.post("/for_agent/{agent_id}/restart_service", response_model=APIResponse)
@handle_exceptions
async def agent_restart_service(agent_id: str, request: Dict[str, str]):
    """Agent 级别重启服务"""
    validate_agent_id(agent_id)
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        context = store.for_agent(agent_id)

        # 获取服务配置
        service_info = await context.get_service_info_async(service_name)
        if not service_info:
            raise HTTPException(status_code=404, detail=f"Service {service_name} not found")

        # 删除服务
        delete_result = await context.delete_service_async(service_name)
        if not delete_result:
            raise HTTPException(status_code=500, detail=f"Failed to stop service {service_name}")

        # 重新添加服务
        add_result = await context.add_service_async([service_name])

        return APIResponse(
            success=add_result,
            data=add_result,
            message=f"Service {service_name} restarted successfully" if add_result else f"Failed to restart service {service_name}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to restart service {service_name}: {str(e)}"
        )

# === Store 级别批量操作 ===
@router.post("/for_store/batch_add_services", response_model=APIResponse)
@handle_exceptions
async def store_batch_add_services(request: Dict[str, List[Any]]):
    """Store 级别批量添加服务"""
    services = request.get("services", [])
    if not services:
        raise HTTPException(status_code=400, detail="Services list is required")

    store = get_store()


    context = store.for_store()
    results = []

    for i, service in enumerate(services):
        try:
            if isinstance(service, str):
                # 服务名方式
                result = await context.add_service_async([service])
            elif isinstance(service, dict):
                # 配置方式
                result = await context.add_service_async(service)
            else:
                results.append({
                    "index": i,
                    "success": False,
                    "message": "Invalid service format"
                })
                continue

            # add_service返回MCPStoreContext对象，表示成功
            success = result is not None
            results.append({
                "index": i,
                "service": service,
                "success": success,
                "message": f"Add operation {'succeeded' if success else 'failed'}"
            })

        except Exception as e:
            results.append({
                "index": i,
                "service": service,
                "success": False,
                "message": str(e)
            })

    success_count = sum(1 for r in results if r.get("success", False))
    total_count = len(results)

    return APIResponse(
        success=success_count > 0,
        data={
            "results": results,
            "summary": {
                "total": total_count,
                "succeeded": success_count,
                "failed": total_count - success_count
            }
        },
        message=f"Batch add completed: {success_count}/{total_count} succeeded"
    )

@router.post("/for_store/batch_update_services", response_model=APIResponse)
@handle_exceptions
async def store_batch_update_services(request: Dict[str, List[Dict[str, Any]]]):
    """Store 级别批量更新服务"""
    updates = request.get("updates", [])
    if not updates:
        raise HTTPException(status_code=400, detail="Updates list is required")

    store = get_store()


    context = store.for_store()
    results = []

    for i, update in enumerate(updates):
        if not isinstance(update, dict):
            results.append({
                "index": i,
                "success": False,
                "message": "Invalid update format"
            })
            continue

        name = update.get("name")
        config = update.get("config")

        if not name or not config:
            results.append({
                "index": i,
                "success": False,
                "message": "Name and config are required"
            })
            continue

        try:
            result = await context.update_service_async(name, config)
            results.append({
                "index": i,
                "name": name,
                "success": result,
                "message": f"Update operation {'succeeded' if result else 'failed'}"
            })

        except Exception as e:
            results.append({
                "index": i,
                "name": name,
                "success": False,
                "message": str(e)
            })

    success_count = sum(1 for r in results if r.get("success", False))
    total_count = len(results)

    return APIResponse(
        success=success_count > 0,
        data={
            "results": results,
            "summary": {
                "total": total_count,
                "succeeded": success_count,
                "failed": total_count - success_count
            }
        },
        message=f"Batch update completed: {success_count}/{total_count} succeeded"
    )

# === Agent 级别批量操作 ===
@router.post("/for_agent/{agent_id}/batch_add_services", response_model=APIResponse)
@handle_exceptions
async def agent_batch_add_services(agent_id: str, request: Dict[str, List[Any]]):
    """Agent 级别批量添加服务"""
    validate_agent_id(agent_id)
    services = request.get("services", [])
    if not services:
        raise HTTPException(status_code=400, detail="Services list is required")

    context = store.for_agent(agent_id)
    # 使用SDK的批量操作方法
    result = await context.batch_add_services_async(services)

    return APIResponse(
        success=result["success"],
        data={
            "results": result["results"],
            "summary": result["summary"]
        },
        message=result["message"]
    )

@router.post("/for_agent/{agent_id}/batch_update_services", response_model=APIResponse)
@handle_exceptions
async def agent_batch_update_services(agent_id: str, request: Dict[str, List[Dict[str, Any]]]):
    """Agent 级别批量更新服务"""
    validate_agent_id(agent_id)
    updates = request.get("updates", [])
    if not updates:
        raise HTTPException(status_code=400, detail="Updates list is required")

    context = store.for_agent(agent_id)
    results = []

    for i, update in enumerate(updates):
        if not isinstance(update, dict):
            results.append({
                "index": i,
                "success": False,
                "message": "Invalid update format"
            })
            continue

        name = update.get("name")
        config = update.get("config")

        if not name or not config:
            results.append({
                "index": i,
                "success": False,
                "message": "Name and config are required"
            })
            continue

        try:
            result = await context.update_service_async(name, config)
            results.append({
                "index": i,
                "name": name,
                "success": result,
                "message": f"Update operation {'succeeded' if result else 'failed'}"
            })

        except Exception as e:
            results.append({
                "index": i,
                "name": name,
                "success": False,
                "message": str(e)
            })

    success_count = sum(1 for r in results if r.get("success", False))
    total_count = len(results)

    return APIResponse(
        success=success_count > 0,
        data={
            "results": results,
            "summary": {
                "total": total_count,
                "succeeded": success_count,
                "failed": total_count - success_count
            }
        },
        message=f"Batch update completed: {success_count}/{total_count} succeeded"
    )

# === Store 级别服务信息查询 ===
@router.post("/for_store/get_service_info", response_model=APIResponse)
@handle_exceptions
async def store_get_service_info(request: Dict[str, str]):
    """Store 级别获取服务信息"""
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        store = get_store()

        store = get_store()


        result = await store.for_store().get_service_info_async(service_name)

        # 检查服务是否存在 - 主要检查service字段是否为None
        if (not result or
            (hasattr(result, 'service') and result.service is None) or
            (isinstance(result, dict) and result.get('service') is None)):
            raise HTTPException(status_code=404, detail=f"Service '{service_name}' not found")

        return APIResponse(
            success=True,
            data=result,
            message=f"Service '{service_name}' information retrieved successfully"
        )
    except HTTPException:
        raise
    except Exception as e:
        # 如果是服务不存在的错误，返回404
        error_msg = str(e).lower()
        if "not found" in error_msg or "does not exist" in error_msg:
            raise HTTPException(status_code=404, detail=f"Service '{service_name}' not found")
        else:
            raise HTTPException(status_code=500, detail=f"Failed to get service info: {str(e)}")

# === Agent 级别服务信息查询 ===
@router.post("/for_agent/{agent_id}/get_service_info", response_model=APIResponse)
@handle_exceptions
async def agent_get_service_info(agent_id: str, request: Dict[str, str]):
    """Agent 级别获取服务信息"""
    validate_agent_id(agent_id)
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        result = await store.for_agent(agent_id).get_service_info_async(service_name)

        # 检查服务是否存在 - 主要检查service字段是否为None
        if (not result or
            (hasattr(result, 'service') and result.service is None) or
            (isinstance(result, dict) and result.get('service') is None)):
            raise HTTPException(status_code=404, detail=f"Service '{service_name}' not found for agent '{agent_id}'")

        return APIResponse(
            success=True,
            data=result,
            message=f"Service '{service_name}' information retrieved successfully for agent '{agent_id}'"
        )
    except HTTPException:
        raise
    except Exception as e:
        # 如果是服务不存在的错误，返回404
        error_msg = str(e).lower()
        if "not found" in error_msg or "does not exist" in error_msg:
            raise HTTPException(status_code=404, detail=f"Service '{service_name}' not found for agent '{agent_id}'")
        else:
            raise HTTPException(status_code=500, detail=f"Failed to get service info for agent '{agent_id}': {str(e)}")

# === Store 级别配置管理 ===
@router.get("/for_store/get_config", response_model=APIResponse)
@handle_exceptions
async def store_get_config():
    """Store 级别获取配置"""
    store = get_store()

    return store.get_json_config()

@router.get("/for_store/show_mcpconfig", response_model=APIResponse)
@handle_exceptions
async def store_show_mcpconfig():
    """Store 级别查看MCP配置"""
    try:
        config = store.for_store().show_mcpconfig()
        return APIResponse(
            success=True,
            data=config,
            message="Store MCP configuration retrieved successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get Store MCP configuration: {str(e)}"
        )

@router.post("/for_store/update_config", response_model=APIResponse)
@handle_exceptions
async def store_update_config(payload: JsonUpdateRequest):
    """Store 级别更新配置"""
    if not payload.config:
        raise HTTPException(status_code=400, detail="Config is required")
    store = get_store()

    return await store.update_json_service(payload)

@router.get("/for_store/validate_config", response_model=APIResponse)
@handle_exceptions
async def store_validate_config():
    """Store 级别验证配置有效性"""
    try:
        store = get_store()

        config = store.get_json_config()
        is_valid = bool(config and isinstance(config, dict))

        return APIResponse(
            success=is_valid,
            data={
                "valid": is_valid,
                "config": config
            },
            message="Configuration is valid" if is_valid else "Configuration is invalid"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={"valid": False},
            message=f"Configuration validation failed: {str(e)}"
        )

@router.post("/for_store/reload_config", response_model=APIResponse)
@handle_exceptions
async def store_reload_config():
    """Store 级别重新加载配置"""
    try:
        store = get_store()

        await store.orchestrator.refresh_services()
        return APIResponse(
            success=True,
            data=True,
            message="Configuration reloaded successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to reload configuration: {str(e)}"
        )

# === Agent 级别配置管理 ===
@router.get("/for_agent/{agent_id}/get_config", response_model=APIResponse)
@handle_exceptions
async def agent_get_config(agent_id: str):
    """Agent 级别获取配置"""
    validate_agent_id(agent_id)
    try:
        config = store.get_json_config(agent_id)
        return APIResponse(
            success=True,
            data=config,
            message=f"Configuration retrieved successfully for agent '{agent_id}'"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get configuration for agent '{agent_id}': {str(e)}"
        )

@router.get("/for_agent/{agent_id}/show_mcpconfig", response_model=APIResponse)
@handle_exceptions
async def agent_show_mcpconfig(agent_id: str):
    """Agent 级别查看MCP配置"""
    validate_agent_id(agent_id)
    try:
        config = store.for_agent(agent_id).show_mcpconfig()
        return APIResponse(
            success=True,
            data=config,
            message=f"Agent MCP configuration retrieved successfully for agent '{agent_id}'"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get Agent MCP configuration for agent '{agent_id}': {str(e)}"
        )

@router.post("/for_agent/{agent_id}/update_config", response_model=APIResponse)
@handle_exceptions
async def agent_update_config(agent_id: str, payload: JsonUpdateRequest):
    """Agent 级别更新配置"""
    validate_agent_id(agent_id)
    if not payload.config:
        raise HTTPException(status_code=400, detail="Config is required")
    payload.client_id = agent_id  # 确保使用正确的agent_id
    store = get_store()

    return await store.update_json_service(payload)

@router.get("/for_agent/{agent_id}/validate_config", response_model=APIResponse)
@handle_exceptions
async def agent_validate_config(agent_id: str):
    """Agent 级别验证配置有效性"""
    validate_agent_id(agent_id)
    try:
        config = store.get_json_config(agent_id)
        is_valid = bool(config and isinstance(config, dict))

        return APIResponse(
            success=is_valid,
            data={
                "valid": is_valid,
                "config": config
            },
            message="Configuration is valid" if is_valid else "Configuration is invalid"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={"valid": False},
            message=f"Configuration validation failed: {str(e)}"
        )

# === Store 级别统计和监控 ===
@router.get("/for_store/get_stats", response_model=APIResponse)
@handle_exceptions
async def store_get_stats():
    """Store 级别获取系统统计信息"""
    try:
        store = get_store()

        context = store.for_store()
        # 使用SDK的统计方法
        stats = context.get_system_stats()

        return APIResponse(
            success=True,
            data=stats,
            message="System statistics retrieved successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get system statistics: {str(e)}"
        )

# === Agent 级别统计和监控 ===
@router.get("/for_agent/{agent_id}/get_stats", response_model=APIResponse)
@handle_exceptions
async def agent_get_stats(agent_id: str):
    """Agent 级别获取系统统计信息"""
    validate_agent_id(agent_id)
    try:
        context = store.for_agent(agent_id)
        # 使用SDK的统计方法
        stats = context.get_system_stats()

        return APIResponse(
            success=True,
            data=stats,
            message="System statistics retrieved successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get system statistics: {str(e)}"
        )

# === Store 级别服务状态查询 ===
@router.post("/for_store/get_service_status", response_model=APIResponse)
@handle_exceptions
async def store_get_service_status(request: Dict[str, str]):
    """Store 级别获取服务详细状态信息"""
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        store = get_store()

        context = store.for_store()

        # 获取服务信息
        service_info = await context.get_service_info_async(service_name)
        if not service_info:
            raise HTTPException(status_code=404, detail=f"Service {service_name} not found")

        # 获取健康状态
        health_check = await context.check_services_async()
        service_health = None

        if isinstance(health_check, dict) and "services" in health_check:
            for service in health_check["services"]:
                if service.get("name") == service_name:
                    service_health = service
                    break

        # 获取工具列表
        tools = await context.list_tools_async()
        service_tools = [tool for tool in tools if getattr(tool, 'service_name', '') == service_name] if tools else []

        status_info = {
            "service": service_info,
            "health": service_health,
            "tools": {
                "count": len(service_tools),
                "list": service_tools
            },
            "last_check": health_check.get("timestamp") if isinstance(health_check, dict) else None
        }

        return APIResponse(
            success=True,
            data=status_info,
            message=f"Service {service_name} status retrieved successfully"
        )
    except HTTPException:
        raise
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get service status: {str(e)}"
        )

# === Agent 级别服务状态查询 ===
@router.post("/for_agent/{agent_id}/get_service_status", response_model=APIResponse)
@handle_exceptions
async def agent_get_service_status(agent_id: str, request: Dict[str, str]):
    """Agent 级别获取服务详细状态信息"""
    validate_agent_id(agent_id)
    service_name = request.get("name")
    if not service_name:
        raise HTTPException(status_code=400, detail="Service name is required")

    try:
        context = store.for_agent(agent_id)

        # 获取服务信息
        service_info = await context.get_service_info_async(service_name)
        if not service_info:
            raise HTTPException(status_code=404, detail=f"Service {service_name} not found")

        # 获取健康状态
        health_check = await context.check_services_async()
        service_health = None

        if isinstance(health_check, dict) and "services" in health_check:
            for service in health_check["services"]:
                if service.get("name") == service_name:
                    service_health = service
                    break

        # 获取工具列表
        tools = await context.list_tools_async()
        service_tools = [tool for tool in tools if getattr(tool, 'service_name', '') == service_name] if tools else []

        status_info = {
            "service": service_info,
            "health": service_health,
            "tools": {
                "count": len(service_tools),
                "list": service_tools
            },
            "last_check": health_check.get("timestamp") if isinstance(health_check, dict) else None
        }

        return APIResponse(
            success=True,
            data=status_info,
            message=f"Service {service_name} status retrieved successfully"
        )
    except HTTPException:
        raise
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get service status: {str(e)}"
        )

# === Store 级别健康检查 ===
@router.get("/for_store/health", response_model=APIResponse)
@handle_exceptions
async def store_health_check():
    """Store 级别系统健康检查"""
    try:
        # 检查Store级别健康状态
        store = get_store()

        store_health = await store.for_store().check_services_async()

        # 基本系统信息
        health_info = {
            "status": "healthy",
            "timestamp": store_health.get("timestamp") if isinstance(store_health, dict) else None,
            "store": store_health,
            "system": {
                "api_version": "0.2.0",
                "store_initialized": bool(store),
                "orchestrator_status": store_health.get("orchestrator_status", "unknown") if isinstance(store_health, dict) else "unknown",
                "context": "store"
            }
        }

        # 判断整体健康状态
        is_healthy = True
        if isinstance(store_health, dict):
            if store_health.get("orchestrator_status") != "running":
                is_healthy = False

            services = store_health.get("services", [])
            if services:
                unhealthy_count = sum(1 for s in services if s.get("status") != "healthy")
                if unhealthy_count > 0:
                    health_info["system"]["unhealthy_services"] = unhealthy_count
                    # 如果有不健康的服务，但系统仍在运行，标记为degraded
                    if is_healthy:
                        health_info["status"] = "degraded"
        else:
            is_healthy = False

        if not is_healthy:
            health_info["status"] = "unhealthy"

        return APIResponse(
            success=is_healthy,
            data=health_info,
            message=f"System status: {health_info['status']}"
        )

    except Exception as e:
        return APIResponse(
            success=False,
            data={
                "status": "unhealthy",
                "error": str(e),
                "context": "store"
            },
            message=f"Health check failed: {str(e)}"
        )

# === Agent 级别健康检查 ===
@router.get("/for_agent/{agent_id}/health", response_model=APIResponse)
@handle_exceptions
async def agent_health_check(agent_id: str):
    """Agent 级别系统健康检查"""
    validate_agent_id(agent_id)
    try:
        # 检查Agent级别健康状态
        store = get_store()
        agent_health = await store.for_agent(agent_id).check_services()

        # 基本系统信息
        health_info = {
            "status": "healthy",
            "timestamp": agent_health.get("timestamp") if isinstance(agent_health, dict) else None,
            "agent": agent_health,
            "system": {
                "api_version": "0.2.0",
                "store_initialized": bool(store),
                "orchestrator_status": agent_health.get("orchestrator_status", "unknown") if isinstance(agent_health, dict) else "unknown",
                "context": "agent",
                "agent_id": agent_id
            }
        }

        # 判断整体健康状态
        is_healthy = True
        if isinstance(agent_health, dict):
            if agent_health.get("orchestrator_status") != "running":
                is_healthy = False

            services = agent_health.get("services", [])
            if services:
                unhealthy_count = sum(1 for s in services if s.get("status") != "healthy")
                if unhealthy_count > 0:
                    health_info["system"]["unhealthy_services"] = unhealthy_count
                    # 如果有不健康的服务，但系统仍在运行，标记为degraded
                    if is_healthy:
                        health_info["status"] = "degraded"
        else:
            is_healthy = False

        if not is_healthy:
            health_info["status"] = "unhealthy"

        return APIResponse(
            success=is_healthy,
            data=health_info,
            message=f"System status: {health_info['status']}"
        )

    except Exception as e:
        return APIResponse(
            success=False,
            data={
                "status": "unhealthy",
                "error": str(e),
                "context": "agent",
                "agent_id": agent_id
            },
            message=f"Health check failed: {str(e)}"
        )

# === Store 级别重置配置 ===
@router.post("/for_store/reset_config", response_model=APIResponse)
@handle_exceptions
async def store_reset_config():
    """Store 级别重置配置"""
    try:
        store = get_store()

        store = get_store()


        success = await store.for_store().reset_config()
        return APIResponse(
            success=success,
            data=success,
            message="Store configuration reset successfully" if success else "Failed to reset store configuration"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to reset store configuration: {str(e)}"
        )

# === Store 级别文件直接重置 ===
@router.post("/for_store/reset_mcp_json_file", response_model=APIResponse)
@handle_exceptions
async def store_reset_mcp_json_file():
    """Store 级别直接重置MCP JSON配置文件"""
    try:
        store = get_store()

        store = get_store()


        success = await store.for_store().reset_mcp_json_file()
        return APIResponse(
            success=success,
            data=success,
            message="MCP JSON file reset successfully" if success else "Failed to reset MCP JSON file"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to reset MCP JSON file: {str(e)}"
        )

@router.post("/for_store/reset_client_services_file", response_model=APIResponse)
@handle_exceptions
async def store_reset_client_services_file():
    """Store 级别直接重置client_services.json文件"""
    try:
        store = get_store()

        store = get_store()


        success = await store.for_store().reset_client_services_file()
        return APIResponse(
            success=success,
            data=success,
            message="client_services.json file reset successfully" if success else "Failed to reset client_services.json file"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to reset client_services.json file: {str(e)}"
        )

@router.post("/for_store/reset_agent_clients_file", response_model=APIResponse)
@handle_exceptions
async def store_reset_agent_clients_file():
    """Store 级别直接重置agent_clients.json文件"""
    try:
        store = get_store()

        store = get_store()


        success = await store.for_store().reset_agent_clients_file()
        return APIResponse(
            success=success,
            data=success,
            message="agent_clients.json file reset successfully" if success else "Failed to reset agent_clients.json file"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to reset agent_clients.json file: {str(e)}"
        )


# === Agent 级别重置配置 ===
@router.post("/for_agent/{agent_id}/reset_config", response_model=APIResponse)
@handle_exceptions
async def agent_reset_config(agent_id: str):
    """Agent 级别重置配置"""
    validate_agent_id(agent_id)
    try:
        success = await store.for_agent(agent_id).reset_config()
        return APIResponse(
            success=success,
            data=success,
            message=f"Agent {agent_id} configuration reset successfully" if success else f"Failed to reset agent {agent_id} configuration"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data=False,
            message=f"Failed to reset agent {agent_id} configuration: {str(e)}"
        )

# === 监控状态API ===
@router.get("/monitoring/status", response_model=APIResponse)
@handle_exceptions
async def get_monitoring_status():
    """获取监控系统状态"""
    try:
        orchestrator = store.orchestrator

        # 获取监控任务状态
        heartbeat_active = orchestrator.heartbeat_task and not orchestrator.heartbeat_task.done()
        reconnection_active = orchestrator.reconnection_task and not orchestrator.reconnection_task.done()
        cleanup_active = orchestrator.cleanup_task and not orchestrator.cleanup_task.done()

        # 获取智能重连队列状态
        reconnection_status = orchestrator.smart_reconnection.get_queue_status()

        # 获取服务统计
        total_services = 0
        healthy_services = 0
        for client_id, services in orchestrator.registry.sessions.items():
            total_services += len(services)
            for service_name in services:
                if await orchestrator.is_service_healthy(service_name, client_id):
                    healthy_services += 1

        status_data = {
            "monitoring_tasks": {
                "heartbeat_active": heartbeat_active,
                "reconnection_active": reconnection_active,
                "cleanup_active": cleanup_active,
                "heartbeat_interval_seconds": orchestrator.heartbeat_interval.total_seconds(),
                "reconnection_interval_seconds": orchestrator.reconnection_interval.total_seconds(),
                "cleanup_interval_seconds": orchestrator.cleanup_interval.total_seconds()
            },
            "service_statistics": {
                "total_services": total_services,
                "healthy_services": healthy_services,
                "unhealthy_services": total_services - healthy_services,
                "health_percentage": round((healthy_services / total_services * 100) if total_services > 0 else 0, 2)
            },
            "reconnection_queue": reconnection_status,
            "resource_limits": {
                "max_reconnection_queue_size": orchestrator.max_reconnection_queue_size,
                "max_heartbeat_history_hours": orchestrator.max_heartbeat_history_hours,
                "http_timeout_seconds": orchestrator.http_timeout
            }
        }

        return APIResponse(
            success=True,
            data=status_data,
            message="Monitoring status retrieved successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get monitoring status: {str(e)}"
        )

@router.post("/monitoring/config", response_model=APIResponse)
@handle_exceptions
async def update_monitoring_config(config: MonitoringConfig):
    """更新监控配置"""
    try:
        orchestrator = store.orchestrator
        updated_fields = []

        # 更新心跳间隔
        if config.heartbeat_interval_seconds is not None:
            orchestrator.heartbeat_interval = timedelta(seconds=config.heartbeat_interval_seconds)
            updated_fields.append(f"heartbeat_interval: {config.heartbeat_interval_seconds}s")

        # 更新重连间隔
        if config.reconnection_interval_seconds is not None:
            orchestrator.reconnection_interval = timedelta(seconds=config.reconnection_interval_seconds)
            updated_fields.append(f"reconnection_interval: {config.reconnection_interval_seconds}s")

        # 更新清理间隔
        if config.cleanup_interval_hours is not None:
            orchestrator.cleanup_interval = timedelta(hours=config.cleanup_interval_hours)
            updated_fields.append(f"cleanup_interval: {config.cleanup_interval_hours}h")

        # 更新重连队列大小
        if config.max_reconnection_queue_size is not None:
            orchestrator.max_reconnection_queue_size = config.max_reconnection_queue_size
            updated_fields.append(f"max_reconnection_queue_size: {config.max_reconnection_queue_size}")

        # 更新心跳历史保留时间
        if config.max_heartbeat_history_hours is not None:
            orchestrator.max_heartbeat_history_hours = config.max_heartbeat_history_hours
            updated_fields.append(f"max_heartbeat_history_hours: {config.max_heartbeat_history_hours}h")

        # 更新HTTP超时时间
        if config.http_timeout_seconds is not None:
            orchestrator.http_timeout = config.http_timeout_seconds
            updated_fields.append(f"http_timeout: {config.http_timeout_seconds}s")

        if not updated_fields:
            return APIResponse(
                success=True,
                data={},
                message="No configuration changes provided"
            )

        # 重启监控任务以应用新配置
        await orchestrator._restart_monitoring_tasks()

        return APIResponse(
            success=True,
            data={"updated_fields": updated_fields},
            message=f"Monitoring configuration updated: {', '.join(updated_fields)}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to update monitoring configuration: {str(e)}"
        )

@router.post("/monitoring/restart", response_model=APIResponse)
@handle_exceptions
async def restart_monitoring():
    """重启监控任务"""
    try:
        orchestrator = store.orchestrator

        # 停止现有任务
        tasks_to_stop = [
            ("heartbeat", orchestrator.heartbeat_task),
            ("reconnection", orchestrator.reconnection_task),
            ("cleanup", orchestrator.cleanup_task)
        ]

        stopped_tasks = []
        for task_name, task in tasks_to_stop:
            if task and not task.done():
                task.cancel()
                try:
                    await task
                except asyncio.CancelledError:
                    pass
                stopped_tasks.append(task_name)

        # 重新启动监控
        await orchestrator.start_monitoring()

        return APIResponse(
            success=True,
            data={"restarted_tasks": stopped_tasks},
            message=f"Monitoring tasks restarted: {', '.join(stopped_tasks) if stopped_tasks else 'all tasks'}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to restart monitoring: {str(e)}"
        )

# === 批量操作API ===
@router.post("/for_store/batch_update_services", response_model=APIResponse)
@handle_exceptions
async def store_batch_update_services(request: Dict[str, List[Dict]]):
    """Store级别批量更新服务配置"""
    services = request.get("services", [])
    if not services:
        raise HTTPException(status_code=400, detail="Services list is required")

    try:
        store = get_store()

        context = store.for_store()
        results = []

        for service_config in services:
            service_name = service_config.get("name")
            if not service_name:
                results.append({"name": "unknown", "success": False, "error": "Service name is required"})
                continue

            try:
                # 更新服务配置
                result = await context.update_service_async(service_name, service_config)
                results.append({"name": service_name, "success": True, "result": result})
            except Exception as e:
                results.append({"name": service_name, "success": False, "error": str(e)})

        success_count = sum(1 for r in results if r["success"])
        total_count = len(results)

        return APIResponse(
            success=success_count > 0,
            data={
                "results": results,
                "summary": {
                    "total": total_count,
                    "success": success_count,
                    "failed": total_count - success_count
                }
            },
            message=f"Batch update completed: {success_count}/{total_count} services updated successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Batch update failed: {str(e)}"
        )

@router.post("/for_store/batch_restart_services", response_model=APIResponse)
@handle_exceptions
async def store_batch_restart_services(request: Dict[str, List[str]]):
    """Store级别批量重启服务"""
    service_names = request.get("service_names", [])
    if not service_names:
        raise HTTPException(status_code=400, detail="Service names list is required")

    try:
        store = get_store()

        context = store.for_store()
        results = []

        for service_name in service_names:
            try:
                # 重启服务
                result = context.restart_service(service_name)
                results.append({"name": service_name, "success": True, "result": result})
            except Exception as e:
                results.append({"name": service_name, "success": False, "error": str(e)})

        success_count = sum(1 for r in results if r["success"])
        total_count = len(results)

        return APIResponse(
            success=success_count > 0,
            data={
                "results": results,
                "summary": {
                    "total": total_count,
                    "success": success_count,
                    "failed": total_count - success_count
                }
            },
            message=f"Batch restart completed: {success_count}/{total_count} services restarted successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Batch restart failed: {str(e)}"
        )

@router.post("/for_store/batch_delete_services", response_model=APIResponse)
@handle_exceptions
async def store_batch_delete_services(request: Dict[str, List[str]]):
    """Store级别批量删除服务"""
    service_names = request.get("service_names", [])
    if not service_names:
        raise HTTPException(status_code=400, detail="Service names list is required")

    try:
        store = get_store()

        context = store.for_store()
        results = []

        for service_name in service_names:
            try:
                # 删除服务
                result = await context.delete_service_async(service_name)
                results.append({"name": service_name, "success": True, "result": result})
            except Exception as e:
                results.append({"name": service_name, "success": False, "error": str(e)})

        success_count = sum(1 for r in results if r["success"])
        total_count = len(results)

        return APIResponse(
            success=success_count > 0,
            data={
                "results": results,
                "summary": {
                    "total": total_count,
                    "success": success_count,
                    "failed": total_count - success_count
                }
            },
            message=f"Batch delete completed: {success_count}/{total_count} services deleted successfully"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Batch delete failed: {str(e)}"
        )
    except Exception as e:
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to restart monitoring: {str(e)}"
        )

# === 监控和统计API ===

@router.get("/for_store/performance_metrics", response_model=APIResponse)
async def get_store_performance_metrics(store: MCPStore = Depends(get_store)):
    """获取Store级别的性能指标"""
    try:
        store = get_store()

        metrics = await store.for_store().get_performance_metrics_async()

        return APIResponse(
            success=True,
            data=PerformanceMetricsResponse(
                api_response_time=metrics.api_response_time,
                active_connections=metrics.active_connections,
                today_api_calls=metrics.today_api_calls,
                memory_usage=metrics.memory_usage,
                cpu_usage=metrics.cpu_usage,
                uptime=metrics.uptime
            ).dict(),
            message="Performance metrics retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get performance metrics: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get performance metrics: {str(e)}"
        )

@router.get("/for_agent/{agent_id}/performance_metrics", response_model=APIResponse)
async def get_agent_performance_metrics(agent_id: str, store: MCPStore = Depends(get_store)):
    """获取Agent级别的性能指标"""
    try:
        validate_agent_id(agent_id)
        metrics = await store.for_agent(agent_id).get_performance_metrics_async()

        return APIResponse(
            success=True,
            data=PerformanceMetricsResponse(
                api_response_time=metrics.api_response_time,
                active_connections=metrics.active_connections,
                today_api_calls=metrics.today_api_calls,
                memory_usage=metrics.memory_usage,
                cpu_usage=metrics.cpu_usage,
                uptime=metrics.uptime
            ).dict(),
            message=f"Agent '{agent_id}' performance metrics retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get agent performance metrics: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get agent performance metrics: {str(e)}"
        )

@router.get("/for_store/tool_usage_stats", response_model=APIResponse)
async def get_store_tool_usage_stats(limit: int = 10, store: MCPStore = Depends(get_store)):
    """获取Store级别的工具使用统计"""
    try:
        store = get_store()

        stats = await store.for_store().get_tool_usage_stats_async(limit)

        stats_data = [
            ToolUsageStatsResponse(
                tool_name=stat.tool_name,
                service_name=stat.service_name,
                execution_count=stat.execution_count,
                last_executed=stat.last_executed,
                average_response_time=stat.average_response_time,
                success_rate=stat.success_rate
            ).dict() for stat in stats
        ]

        return APIResponse(
            success=True,
            data=stats_data,
            message="Tool usage statistics retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get tool usage stats: {e}")
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to get tool usage stats: {str(e)}"
        )

@router.get("/for_agent/{agent_id}/tool_usage_stats", response_model=APIResponse)
async def get_agent_tool_usage_stats(agent_id: str, limit: int = 10, store: MCPStore = Depends(get_store)):
    """获取Agent级别的工具使用统计"""
    try:
        validate_agent_id(agent_id)
        stats = await store.for_agent(agent_id).get_tool_usage_stats_async(limit)

        stats_data = [
            ToolUsageStatsResponse(
                tool_name=stat.tool_name,
                service_name=stat.service_name,
                execution_count=stat.execution_count,
                last_executed=stat.last_executed,
                average_response_time=stat.average_response_time,
                success_rate=stat.success_rate
            ).dict() for stat in stats
        ]

        return APIResponse(
            success=True,
            data=stats_data,
            message=f"Agent '{agent_id}' tool usage statistics retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get agent tool usage stats: {e}")
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to get agent tool usage stats: {str(e)}"
        )

@router.get("/for_store/alerts", response_model=APIResponse)
async def get_store_alerts(unresolved_only: bool = False, store: MCPStore = Depends(get_store)):
    """获取Store级别的告警列表"""
    try:
        store = get_store()

        alerts = await store.for_store().get_alerts_async(unresolved_only)

        alerts_data = [
            AlertInfoResponse(
                alert_id=alert.alert_id,
                type=alert.type,
                title=alert.title,
                message=alert.message,
                timestamp=alert.timestamp,
                service_name=alert.service_name,
                resolved=alert.resolved
            ).dict() for alert in alerts
        ]

        return APIResponse(
            success=True,
            data=alerts_data,
            message="Alerts retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get alerts: {e}")
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to get alerts: {str(e)}"
        )

@router.post("/for_store/alerts", response_model=APIResponse)
async def add_store_alert(request: AddAlertRequest, store: MCPStore = Depends(get_store)):
    """添加Store级别的告警"""
    try:
        store = get_store()

        alert_id = await store.for_store().add_alert_async(
            request.type, request.title, request.message, request.service_name
        )

        return APIResponse(
            success=True,
            data={"alert_id": alert_id},
            message="Alert added successfully"
        )
    except Exception as e:
        logger.error(f"Failed to add alert: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to add alert: {str(e)}"
        )

@router.put("/for_store/alerts/{alert_id}/resolve", response_model=APIResponse)
async def resolve_store_alert(alert_id: str, store: MCPStore = Depends(get_store)):
    """解决Store级别的告警"""
    try:
        store = get_store()

        store = get_store()


        success = await store.for_store().resolve_alert_async(alert_id)

        if success:
            return APIResponse(
                success=True,
                data={},
                message="Alert resolved successfully"
            )
        else:
            return APIResponse(
                success=False,
                data={},
                message="Alert not found or already resolved"
            )
    except Exception as e:
        logger.error(f"Failed to resolve alert: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to resolve alert: {str(e)}"
        )

@router.delete("/for_store/alerts", response_model=APIResponse)
async def clear_store_alerts(store: MCPStore = Depends(get_store)):
    """清除Store级别的所有告警"""
    try:
        store = get_store()

        store = get_store()


        success = await store.for_store().clear_all_alerts_async()

        if success:
            return APIResponse(
                success=True,
                data={},
                message="All alerts cleared successfully"
            )
        else:
            return APIResponse(
                success=False,
                data={},
                message="Failed to clear alerts"
            )
    except Exception as e:
        logger.error(f"Failed to clear alerts: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to clear alerts: {str(e)}"
        )

@router.post("/for_store/network_check", response_model=APIResponse)
async def check_store_network_endpoints(request: NetworkEndpointCheckRequest, store: MCPStore = Depends(get_store)):
    """检查Store级别的网络端点状态"""
    try:
        store = get_store()

        endpoints = await store.for_store().check_network_endpoints(request.endpoints)

        endpoints_data = [
            NetworkEndpointResponse(
                endpoint_name=endpoint.endpoint_name,
                url=endpoint.url,
                status=endpoint.status,
                response_time=endpoint.response_time,
                last_checked=endpoint.last_checked,
                uptime_percentage=endpoint.uptime_percentage
            ).dict() for endpoint in endpoints
        ]

        return APIResponse(
            success=True,
            data=endpoints_data,
            message="Network endpoints checked successfully"
        )
    except Exception as e:
        logger.error(f"Failed to check network endpoints: {e}")
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to check network endpoints: {str(e)}"
        )

@router.get("/for_store/system_resources", response_model=APIResponse)
async def get_store_system_resources(store: MCPStore = Depends(get_store)):
    """获取Store级别的系统资源信息"""
    try:
        store = get_store()

        resources = await store.for_store().get_system_resource_info_async()

        return APIResponse(
            success=True,
            data=SystemResourceInfoResponse(
                server_uptime=resources.server_uptime,
                memory_total=resources.memory_total,
                memory_used=resources.memory_used,
                memory_percentage=resources.memory_percentage,
                disk_usage_percentage=resources.disk_usage_percentage,
                network_traffic_in=resources.network_traffic_in,
                network_traffic_out=resources.network_traffic_out
            ).dict(),
            message="System resources retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get system resources: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to get system resources: {str(e)}"
        )

# Agent级别的告警API (简化版，复用Store的逻辑)
@router.get("/for_agent/{agent_id}/alerts", response_model=APIResponse)
async def get_agent_alerts(agent_id: str, unresolved_only: bool = False, store: MCPStore = Depends(get_store)):
    """获取Agent级别的告警列表"""
    try:
        validate_agent_id(agent_id)
        alerts = await store.for_agent(agent_id).get_alerts_async(unresolved_only)

        alerts_data = [
            AlertInfoResponse(
                alert_id=alert.alert_id,
                type=alert.type,
                title=alert.title,
                message=alert.message,
                timestamp=alert.timestamp,
                service_name=alert.service_name,
                resolved=alert.resolved
            ).dict() for alert in alerts
        ]

        return APIResponse(
            success=True,
            data=alerts_data,
            message=f"Agent '{agent_id}' alerts retrieved successfully"
        )
    except Exception as e:
        logger.error(f"Failed to get agent alerts: {e}")
        return APIResponse(
            success=False,
            data=[],
            message=f"Failed to get agent alerts: {str(e)}"
        )

@router.post("/for_agent/{agent_id}/alerts", response_model=APIResponse)
async def add_agent_alert(agent_id: str, request: AddAlertRequest, store: MCPStore = Depends(get_store)):
    """添加Agent级别的告警"""
    try:
        validate_agent_id(agent_id)
        alert_id = await store.for_agent(agent_id).add_alert_async(
            request.type, request.title, request.message, request.service_name
        )

        return APIResponse(
            success=True,
            data={"alert_id": alert_id},
            message=f"Alert added to agent '{agent_id}' successfully"
        )
    except Exception as e:
        logger.error(f"Failed to add agent alert: {e}")
        return APIResponse(
            success=False,
            data={},
            message=f"Failed to add agent alert: {str(e)}"
        )
